/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 06852
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1993
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 06852-0001-statasetup.do)
 |
 **************************************************************************/

set mem 80m  /* Allocating 80 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Household Survey on Drug Abuse, 1993, Dataset 0001"

#delimit ;
label define CIGTRY    985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CIG5PK    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       91 "NEVER USED CIGARETTES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CIGAGE    981 "NEVER USED CIGARETTES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED CIGARETTES" 993 "NEVER SMOKED DAILY"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CIGYRS    985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define PACKS     1 "One to five cigarettes a day"
                       2 "About 1/2 pack a day (6-15 cigarettes)"
                       3 "About a pack a day (16-25 cigarettes)"
                       4 "About 1 1/2 packs a day (26-35 cigarettes)"
                       5 "About 2 packs or more a day (over 35 cigarettes)"
                       91 "NEVER USED CIGARETTES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIGREC    1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED CIGARETTES" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define AVCIG     1 "Less than one cigarette a day"
                       2 "One to five cigarettes a day"
                       3 "About 1/2 pack a day (6-15 cigarettes)"
                       4 "About a pack a day (16-25 cigarettes)"
                       5 "About 1 1/2 packs a day (26-35 cigarettes)"
                       6 "About 2 packs or more a day (over 35 cigarettes)"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED CIGARETTES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIGTIME   9981 "NEVER USED CIGARETTES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED CIGARETTES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define SNUFREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED SMOKELESS TOBACCO" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTHTOB    1 "Daily in the past 12 Months"
                       2 "Almost daily (3-6 days a week)"
                       3 "1 or 2 days a week"
                       4 "Several times a month (25-51 days a year)"
                       5 "1 or 2 times a month (12-24 days a year)"
                       6 "Every other month or so (6-11 days a year)"
                       7 "3-5 days this past year"
                       8 "1 or 2 days this past year"
                       83 "DID NOT USE SMOKELESS TOBACCO PST YR Logic.assgn."
                       91 "NEVER USED SMOKELESS TOBACCO" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCTRY    981 "NEVER USED ALCOHOL Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL" 994 "DON'T KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define ALCREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       91 "NEVER USED ALCOHOL" ;
label define ALCAGE    981 "NEVER USED ALCOHOL Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL"
                       993 "NEVER USED ALCOHOL MONTHLY OR MORE OFTEN"
                       994 "DON'T KNOW" 998 "BLANK (NO ANSWER)" ;
label define ALCDAYS   81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define NODR30A   81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DR5DAY    81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MODR30A   81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MODR30DY  81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS Logic Asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCPAT    1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days a year)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DRUNKYR   1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days a year)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       9 "Never got very high or drunk in past 12 months"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCBEER   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 94 "DON'T KNOW" ;
label define ALCWINE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" ;
label define ALCLIQR   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" ;
label define ALCVARY   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" ;
label define NOSEDAT   1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY IMPUTED"
                       98 "BLANK (NO ANSWER)" ;
label define BUTISOL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define BUTICAPS  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define AMYTAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define MEBARAL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PLACIDYL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define DORIDEN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define NOLUDAR   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define NEMBUTAL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SECONAL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define TUINAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define DALMANE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define RESTORIL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define HALCION   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define AMOBARB   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PHENOBAR  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define METHAQ    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define CHHYD     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PENTOB    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SECOB     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDNEWA   108 "Nembutal"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       122 "Sleep Aid" 127 "Nytol" 129 "Reds"
                       135 "Mini Thins" 137 "7-14"
                       158 "Calmociteno (in Brazil)" 159 "Octanox" 160 "sic"
                       161 "Rufonol" 162 "sic" 201 "Valium" 206 "Tranxene"
                       209 "Xanax" 224 "Triavil" 311 "Preludin"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       339 "Amphetamines (speed generically)" 369 "Artane"
                       401 "Darvon"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       415 "Codeine" 420 "OTHER Analgesic, NOT SPECIFIED"
                       422 "Motrin" 423 "Percocet" 427 "Darvocet"
                       430 "Aspirin, Ecotrin, Empirin"
                       434 "Co-Gesic, Hydrocodone, Tussionex, Vicodin"
                       435 "Tylenol, Tylenol Extrastrength"
                       456 "see also 434" 704 "Dope" 811 "Muscle relaxers"
                       864 "Dramamine ,Motion sickness pill"
                       981 "NEVER USED SEDATIVES Logically assigned"
                       991 "NEVER USED SEDATIVES" 998 "BLANK (NO ANSWER)" ;
label define SEDNEWB   116 "Methaqualone, Quaalude, Sopor" 209 "Xanax"
                       244 "sic" 247 "Adapin, Doxepin, Sinequan"
                       326 "White cross" 362 "Benadryl" 415 "Codeine"
                       428 "sic" 991 "NEVER USED SEDATIVES"
                       998 "BLANK (NO ANSWER)" ;
label define SEDNEWC   809 "Pills" 991 "NEVER USED SEDATIVES"
                       998 "BLANK (NO ANSWER)" ;
label define SEDNEWD   991 "NEVER USED SEDATIVES" 998 "BLANK (NO ANSWER)" ;
label define SEDNEWE   991 "NEVER USED SEDATIVES" 998 "BLANK (NO ANSWER)" ;
label define SEDNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Sedative use LOGICALLY IMPUTED"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDDKNAM  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDAGE    981 "NEVER USED SEDATIVES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED SEDATIVES" 994 "DON'T KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define SEDTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDREC    1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (25 to 51 days a year)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       83 "DID NOT USE SEDATIVE PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE ANY SEDATIVE IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define TRNREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       98 "BLANK (NO ANSWER)" ;
label define NOTRANQ   1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY IMPUTED"
                       98 "BLANK (NO ANSWER)" ;
label define VALIUM    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define LIBRIUM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define LIMBTROL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MENRIUM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define SERAX     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANXENE  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define ATIVAN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define CENTRAX   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define XANAX     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define PAXIPAM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define BUSPAR    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MILTOWN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define EQUANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DEPROL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define VISTAR    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define ATARAX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DURRAX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DIAZEPAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define SKLY      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MEPROB    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRNEWA    110 "Tuinal" 116 "Methaqualone, Quaalude, Sopor"
                       131 "Haldol, Haloperidol" 201 "Valium" 207 "Ativan"
                       209 "Xanax" 218 "Diazepam"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       227 "Thorazine" 228 "see also 239"
                       234 "Cyclobenzaprine, Flexeril" 239 "see also 228"
                       268 "Rahipinal" 269 "Pasidrin (in Mexico)"
                       270 "Torzien" 336 "Diet pills" 344 "Bennies"
                       415 "Codeine" 422 "Motrin" 427 "Darvocet"
                       430 "Aspirin, Ecotrin, Empirin" 437 "Parafon Forte"
                       438 "Anaprox, Naprosyn" 991 "NEVER USED TRANQUILIZERS"
                       998 "BLANK (NO ANSWER)" ;
label define TRNEWB    128 "Nervine" 226 "Stelazine, Trifluoperazine HCl"
                       991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRNEWC    230 "Compazine" 991 "NEVER USED TRANQUILIZERS"
                       998 "BLANK (NO ANSWER)" ;
label define TRNEWD    991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRNEWE    991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRNOSP    1 "Response circled" 2 "Response not circled"
                       3 "Tranquilizer use LOGICALLY IMPUTED"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRDKNAM   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANAGE   981 "NEVER USED TRANQUILIZERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRANTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRNYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days a year)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       83 "DID NOT USE TRANQUILIZER PAST 12 MOS. Logic.assgnd"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE ANY TRANQUILIZER IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STMREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define NOSTIMS   1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY IMPUTED"
                       98 "BLANK (NO ANSWER)" ;
label define DEXED     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DEXAMYL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define ESKAT     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define BENZ      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define BIPHET    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DESOXYN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define TENUATE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define TEPANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DIDREX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PLEGINE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PRELUDIN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define IONAMIN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define FASTIN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PONDIMIN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define VORANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define SANOREX   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define MAZANOR   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define RITALIN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define CYLERT    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DETAMP    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define METHI     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define METHAMP   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define OBLA      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STIMNEWA  124 "Yellow jackets" 135 "Mini Thins"
                       145 "Red devil(s)" 301 "Dexedrine" 305 "Biphetamine"
                       313 "Fastin, Phentermine" 316 "Sanorex"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       325 "USED STIMULANT, DON'T KNOW NAME"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       328 "Pink hearts" 329 "Robin's eggs, speckled eggs"
                       331 "Whites, Blancas" 332 "see also 346"
                       333 "357 Magnum, Magnum 44"
                       334 "Crossroads, cross tops" 335 "Dexatrim"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)" 344 "Bennies"
                       347 "Phenylpropanolamine" 348 "Crystal" 352 "Lemons"
                       353 "No-Doz" 354 "Vivarin" 355 "Crystal meth"
                       357 "Heart-shaped black pills" 384 "Little crosses"
                       385 "Little pink one" 386 "Ma Huang" 388 "Pink lemon"
                       389 "sic" 390 "Max Alert" 391 "sic"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       430 "Aspirin, Ecotrin, Empirin"
                       435 "Tylenol, Tylenol Extrastrength"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       606 "sic" 621 "Red dragon" 635 "Ginseng seeds"
                       702 "Heroin" 803 "sic" 805 "Cocaine, coke, coca"
                       806 "Crack, rock" 814 "Caffeine" 815 "Coffee"
                       991 "NEVER USED STIMULANTS" 998 "BLANK (NO ANSWER)" ;
label define STIMNEWB  124 "Yellow jackets" 254 "sic" 326 "White cross"
                       327 "Black beauties, Black Beauty" 328 "Pink hearts"
                       332 "see also 346" 334 "Crossroads, cross tops"
                       339 "Amphetamines (speed generically)" 344 "Bennies"
                       353 "No-Doz" 354 "Vivarin" 355 "Crystal meth"
                       363 "Bam(s)" 620 "Blue dragon" 805 "Cocaine, coke"
                       806 "Crack, rock" 814 "Caffeine"
                       991 "NEVER USED STIMULANTS" 998 "BLANK (NO ANSWER)" ;
label define STIMNEWC  374 "Christmas tree(s)" 991 "NEVER USED STIMULANTS"
                       998 "BLANK (NO ANSWER)" ;
label define STIMNEWD  387 "Pink football" 991 "NEVER USED STIMULANTS"
                       998 "BLANK (NO ANSWER)" ;
label define STIMNEWE  991 "NEVER USED STIMULANTS" 998 "BLANK (NO ANSWER)" ;
label define STIMNOSP  1 "Response circled" 2 "Response not circled"
                       3 "Stimulant use LOGICALLY IMPUTED"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STMDKNAM  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STIMAGE   981 "NEVER USED STIMULANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED STIMULANTS" 998 "BLANK (NO ANSWER)" ;
label define STIMTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STIMREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STMYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days a year)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       83 "DID NOT USE STIMULANT PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define STNEEDLE  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       83 "NEVER USED AMPHETAMINES W/A NEEDLE Logic.assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "NEVER USED AMPHETAMINES WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define ANLREAD   1 "Wants interviewer to read questions"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define ANALNONE  1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY IMPUTED"
                       98 "BLANK (NO ANSWER)" ;
label define DARVON    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DOLENE    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define SK65A     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define WYGESIC   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define LEVODRO   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PERCODAN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DEMEROL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DILAUD    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TYLCOD    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PHENCOD   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALWIN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALWINNX  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALACEN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PROPOXY   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define CODEINE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANILERID  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define MORPHINE  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define METHDON   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define STADOL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANALNEWA  234 "Cyclobenzaprine, Flexeril"
                       322 "Methamphetamine (speed or ice or crank)"
                       406 "Oxycodone, Percodan, Roxicet" 407 "Demerol"
                       420 "OTHER Analgesic, NOT SPECIFIED" 422 "Motrin"
                       423 "Percocet" 425 "Advil"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       427 "Darvocet" 430 "Aspirin, Ecotrin, Empirin"
                       431 "Tylox"
                       434 "Co-Gesic, Hydrocodone, Tussionex, Vicodin"
                       435 "Tylenol, Tylenol Extrastrength"
                       438 "Anaprox, Naprosyn" 442 "Ibuprofen" 443 "Dolobid"
                       455 "Fiorinal with Codeine" 470 "Cafergot"
                       471 "Butazolidin" 472 "Indocin, Indomethacin"
                       473 "Pyridium" 474 "sic" 475 "sic"
                       476 "Isocom, Midrin" 477 "Neo-Melubrina (Spanish)"
                       479 "Pentrexyl" 480 "Robitussin AC with Codeine"
                       702 "Heroin" 703 "Opium" 811 "Muscle relaxers"
                       820 "Penicillin" 829 "Robitussin DM"
                       991 "NEVER USED ANALGESICS" 992 "ILLEGIBLE"
                       998 "BLANK (NO ANSWER)" ;
label define ANALNEWB  415 "Codeine" 424 "Fioricet"
                       430 "Aspirin, Ecotrin, Empirin"
                       434 "Co-Gesic, Hydrocodone, Tussionex, Vicodin"
                       443 "Dolobid" 450 "Acetaminophen" 828 "Tetracycline"
                       991 "NEVER USED ANALGESICS" 998 "BLANK (NO ANSWER)" ;
label define ANALNEWC  478 "Nogirtronia" 991 "NEVER USED ANALGESICS"
                       998 "BLANK (NO ANSWER)" ;
label define ANALNEWD  234 "Cyclobenzaprine, Flexeril"
                       991 "NEVER USED ANALGESICS" 998 "BLANK (NO ANSWER)" ;
label define ANALNEWE  991 "NEVER USED ANALGESICS" 998 "BLANK (NO ANSWER)" ;
label define ANLNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Analgesic use LOGICALLY IMPUTED"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANLDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANALAGE   981 "NEVER USED ANALGESICS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ANALGESICS" 994 "DON'T KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define ANALTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED ANALGESICS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define ANALREC   1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANLYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days a year)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED ANALGESICS Logically assigned"
                       83 "DID NOT USE ANALGESICS PAST 12 MO. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESICS IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define MJOPP     981 "NEVER HAD CHANCE TO TRY MARIJUANA Logic.assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER HAD CHANCE TO TRY MARIJUANA"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MJAGE     981 "NEVER USED MARIJUANA Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED MARIJUANA" 994 "DON'T KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define MJTOT     1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MJREC     1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       91 "NEVER USED MARIJUANA" ;
label define MJDAY30A  81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define MJAV30A   81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       94 "DON'T KNOW" 98 "BLANK (NO ANSWER)" ;
label define MJAV30B   81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       94 "DON'T KNOW" 98 "BLANK (NO ANSWER)" ;
label define MJAMT30A  1 "1 to 10 joints in the past 30 days"
                       2 "11 to 20 joints in the past 30 days"
                       3 "About 1 ounce in the past 30 days"
                       4 "About 2 ounces in the past 30 days"
                       5 "3 to 4 ounces in the past 30 days"
                       6 "5 to 6 ounces in the past 30 days"
                       8 "8 ounces in the past 30 days"
                       30 "30 ounces in the past 30 days"
                       55 "Nickel bag in the past 30 days"
                       77 "More than 6 oz. exact amt not spec. in pst 30 days"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define MJFRIEND  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJDEALER  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJOTHSHR  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJGIVEN   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJTRGOOD  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJTRSERV  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJSTOLE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJTRICK   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJGREW    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJOBTNON  2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJBUCK    .0 "Did not spend any money on marijuana pst 30 days"
                       9981.0 "NEVER USED MARIJUANA Logically assigned"
                       9983.0 "DID NOT USE MARIJUANA PST 30 DAYS Logic. assigned"
                       9985.0 "BAD DATA Logically assigned"
                       9991.0 "NEVER USED MARIJUANA"
                       9993.0 "DID NOT USE MARIJUANA IN THE PAST 30 DAYS"
                       9994.0 "DON'T KNOW" 9997.0 "REFUSED"
                       9998.0 "BLANK (NO ANSWER)" ;
label define MJYRFREQ  1 "Several times a day in the past 12 months"
                       2 "Daily in the past 12 months"
                       3 "Almost daily or 3 to 6 days a week"
                       4 "1 or 2 days a week"
                       5 "Several times a month (about 25 to 51 days a year)"
                       6 "1 to 2 times a month (12 to 24 days a year)"
                       7 "Every other month or so (6 to 11 days a year)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 or 2 days in the past 12 months"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJJOINT   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" ;
label define MJPIPE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" ;
label define MJBAKE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" ;
label define MJCHEW    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" ;
label define MJWAY     1 "Response circled, method not specified"
                       2 "Response not circled"
                       4 "PST 30 DAY OR PST 12 MTH MJ USER W/NO Q.M-11 ANS."
                       6 "Can with holes/in a bowl" 7 "One hitter/pinch hit"
                       8 "Boiled with tea"
                       9 "Smoky small room(burn in small room like bathroom)"
                       12 "Chewing/eating/suck on stems/gumming"
                       13 "Through an apple made like a pipe" 14 "sic"
                       15 "Steam roller" 16 "Laced"
                       17 "Blunts/smoked with or in a cigar/in cigar paper"
                       19 "With cocaine" 24 "Drank it"
                       25 "Hash under glass/can/glass bottle"
                       28 "In tobacco paper/rolling paper" 31 "Joint"
                       32 "Pipe/water pipe"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic.assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS" ;
label define MJLFDALY  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED (from UDAYMJ)"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       91 "NEVER USED MARIJUANA" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHREAD   1 "Wants interviewer to read questions"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define GAS       1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (from GAS30A)"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define LGAS      1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (from LGAS30A)"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define SPPAINT   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm SPPAN30A)"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define AEROS     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm AEROS30A)"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define GLUE      1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm GLUE30A)"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define SOLVENT   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm SOLVN30A)"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define AMYLNIT   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm AMLNT30A)"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define ETHER     1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define NITOXID   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm NOX30A)"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define CLEFLU    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm CLFL30A)"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHNEWA   327 "Black beauties, Black Beauty" 348 "Crystal"
                       417 "Morphine" 501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       505 "Lacquer thinner or other paint solvents"
                       506 "Amyl nitrite, poppers, locker rm odorizer,rush"
                       507 "Halothane, ether, or other anesthetics; chloroform"
                       508 "Nitrous oxide, whippets, dentist gas"
                       509 "Corr flds, degreasers, cleaning flds, Liquid Paper"
                       511 "Markers, felt-tip pens, ink pens" 513 "sic"
                       514 "sic" 515 "Vicks" 516 "Freon"
                       518 "Acetone, nail polish remover" 519 "Helium"
                       524 "see also 509" 525 "see also 521,544"
                       526 "Nail polish" 528 "Whipped-cream can"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       539 "ScotchGard" 540 "PAM" 542 "Spirits of ammonia"
                       545 "Car tailpipe exhaust fumes, CO2"
                       553 "Pixie sticks" 555 "Chillers" 558 "Kool Aid"
                       559 "LOLOY" 560 "Soap" 561 "Amputee gas cleanser"
                       562 "Ban apple gas" 563 "Acetylene"
                       565 "Trichloroethane"
                       566 "Smoked tea from Lipton tea bag"
                       567 "Pertussin spray" 568 "Tally" 569 "Peganento"
                       570 "PVC (in Mexico)" 702 "Heroin" 706 "Smack"
                       803 "sic" 805 "Cocaine, coke, coca"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       852 "sic" 900 "Non-Drug reason given for Drug Problem"
                       981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 998 "BLANK (NO ANSWER)" ;
label define INHNEWB   322 "Methamphetamine (speed or ice or crank)"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       508 "Nitrous oxide, whippets, dentist gas"
                       509 "Corr flds, degreasers, cleaning flds, Liquid Paper"
                       511 "Markers, felt-tip pens, ink pens"
                       518 "Acetone, nail polish remover" 519 "Helium"
                       524 "see also 509" 548 "Cologne, rubbing alcohol"
                       556 "Energine" 564 "Electric contact cleaner"
                       818 "Nicotine"
                       981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 998 "BLANK (NO ANSWER)" ;
label define INHNEWC
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       519 "Helium"
                       981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 998 "BLANK (NO ANSWER)" ;
label define INHNEWD   981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 998 "BLANK (NO ANSWER)" ;
label define INHNEWE   981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 998 "BLANK (NO ANSWER)" ;
label define INHNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHDKNAM  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHAGE    981 "NEVER USED INHALANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED INHALANTS" 994 "DON'T KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define INHTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHREC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define GAS30A    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic.assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       94 "DON'T KNOW" 98 "BLANK (NO ANSWER)" ;
label define LGAS30A   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic.assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define SPPAN30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic. assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define AEROS30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic.assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define GLUE30A   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USED INHALANT PAST 30 DAYS Logic.assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define SOLVN30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic.assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define AMLNT30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic.assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define ETHER30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USED INHALANT PAST 30 DAYS Logic.assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define NOX30A    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic.assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define CLFL30A   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic.assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define INNEW30A  348 "Crystal"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       505 "Lacquer thinner or other paint solvents"
                       509 "Corr flds, degreasers, cleaning flds, Liquid Paper"
                       511 "Markers, felt-tip pens, ink pens" 519 "Helium"
                       524 "see also 509" 526 "Nail polish"
                       528 "Whipped-cream can" 539 "ScotchGard"
                       900 "Non-Drug reason given for Drug Problem"
                       981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS IN PAST 30 DAYS"
                       998 "BLANK (NO ANSWER)" ;
label define INNEW30B  519 "Helium"
                       981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS PAST 30 DAYS"
                       998 "BLANK (NO ANSWER)" ;
label define INNEW30C  981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS IN PAST 30 DAYS"
                       998 "BLANK (NO ANSWER)" ;
label define INNEW30D  981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS PAST 30 DAYS"
                       998 "BLANK (NO ANSWER)" ;
label define INNEW30E  981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS IN PAST 30 DAYS"
                       998 "BLANK (NO ANSWER)" ;
label define IN30NOSP  1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic.assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define INH30NO   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       4 "Response not circled LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHDY30A  81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANTS PAST 30 DAYS Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define INHYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days a year)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define INHPO     1 "Yes" 2 "No"
                       81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define INHQNC1   1 "QUESTION 1 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC2   2 "QUESTION 2 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC3   3 "QUESTION 3 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC4   4 "QUESTION 4 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC5   5 "QUESTION 5 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC6   6 "QUESTION 6 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC7   7 "QUESTION 7 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC8   8 "QUESTION 8 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC10  10 "ALL QUESTIONS WERE CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHANSY   1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define COCOPP
                       981 "NEVER HAD A CHANCE TO TRY COCAINE Logic. assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER HAD A CHANCE TO TRY COCAINE IN ANY FORM"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define COCAGE    981 "NEVER USED COCAINE Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED COCAINE" 994 "DON'T KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define COCTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED COCAINE Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define COCREC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED COCAINE Logically assigned"
                       91 "NEVER USED COCAINE" ;
label define COCUS30A  81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 30 DAYS Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" ;
label define COCAM30A  1 "Used some but less than 1/4 gram in past 30 days"
                       2 "About 1/4 gram in the past 30 days"
                       3 "About 1/2 gram in the past 30 days"
                       4 "About 1 gram in the past 30 days"
                       5 "About 2 grams in the past 30 days"
                       6 "About 3 grams in the past 30 days"
                       7 "About 4 grams in the past 30 days"
                       8 "About 5 grams in the past 30 days"
                       10 "About 7 grams in the past 30 days"
                       12 "About 9 grams in the past 30 days"
                       15 "About 12 grams in the past 30 days"
                       19 "About 16 grams in the past 30 days"
                       77 "More than 3 grams exact amt not spec. pst 30 days"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 30 DAYS Logic.assignd"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       94 "DON'T KNOW" 98 "BLANK (NO ANSWER)" ;
label define CCFRIEND  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm CKFRIEND)"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define CCDEALER  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm CKDEALER)"
                       81 "NEVER USED COCAINE Logically Assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define CCOTHSHR  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm CKOTHSHR)"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define CCGIVEN   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm CKGIVEN)"
                       81 "NEVER USED COCAINE Logically Assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define CCTRGOOD  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm CKTRGOOD)"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PST 30 DAYS Logic assgn."
                       97 "REFUSED" ;
label define CCTRSERV  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm CKTRSERV)"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PST 30 DAYS Logic assgn."
                       97 "REFUSED" ;
label define CCSTOLE   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (from CKSTOLE)"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define CCTRICK   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm CKTRICK)"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PST 30 DAYS" 97 "REFUSED" ;
label define CCOBTNON  2 "Response not circled"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define COCBUCK   0 "Did not spend any money on cocaine pst 30 days"
                       9981 "NEVER USED COCAINE Logically assigned"
                       9983 "DID NOT USE COCAINE PAST 30 DAYS Logic.assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED COCAINE"
                       9993 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define COCYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days a year)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 12 MONTHS Logic.assgnd"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 98 "BLANK (NO ANSWER)" ;
label define COCSNIFF  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS" ;
label define COCSWAL   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS" ;
label define COCIV     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm CONDLREC)"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS" ;
label define FREEBASE  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm CRAKREC)"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS" ;
label define COCWAY    1 "Response circled, method not specified"
                       2 "Response not circled"
                       4 "PST 3O DAYS OR PST 12 MTH COC USR W/NO Q.CN-10 ANS"
                       7 "On my gums/mouth" 8 "Freeze, put on tongue"
                       9 "Smoked in a cigarette/Snowcap"
                       10 "Laced with marijuana"
                       11 "Smoked using aluminum foil" 12 "Pop-can bong"
                       13 "Lined with PCP" 14 "Mixed in food" 15 "Sexually"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS" ;
label define CONDLREC  1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "USED COCAINE BUT NEVER W/A NEEDLE Logic. assigned"
                       91 "NEVER USED COCAINE"
                       93 "USED COCAINE BUT NEVER W/A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define CCLFDALY  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY IMPUTED (from UDAYCOC)"
                       81 "NEVER USED COCAINE Logically assigned"
                       91 "NEVER USED COCAINE" 98 "BLANK (NO ANSWER)" ;
label define CRAKREC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED CRACK Logically assigned"
                       91 "NEVER USED CRACK" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CRKAM30A  981 "NEVER USED CRACK Logically assigned"
                       983 "DID NOT USE CRACK IN PAST 30 DAYS Logic.assignd"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED CRACK"
                       993 "DID NOT USE CRACK IN PAST 30 DAYS"
                       994 "DON'T KNOW" 998 "BLANK (NO ANSWER)" ;
label define CKFRIEND  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKDEALER  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKOTHSHR  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKGIVEN   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PST 30 DAYS" 97 "REFUSED" ;
label define CKTRGOOD  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKTRSERV  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKSTOLE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKTRICK   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKOBTNON  2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" ;
label define CRAKBUCK  0 "Did not spend any money on crack pst 30 days"
                       9981 "NEVER USED CRACK Logically assigned"
                       9983 "DID NOT USE CRACK PAST 30 DAYS Logic.assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CRACK"
                       9993 "DID NOT USE CRACK IN PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define CKLFDALY  1 "Yes" 2 "No"
                       81 "NEVER USED CRACK Logically assigned"
                       91 "NEVER USED CRACK" 98 "BLANK (NO ANSWER)" ;
label define HALREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       98 "BLANK (NO ANSWER)" ;
label define LSD       1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PEYOTE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MESC      1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PSILCY    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PCP       1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm PCPREC)"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ECSTASY   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALNEWA   116 "Methaqualone, Quaalude, Sopor" 125 "sic"
                       142 "Belladona" 248 "sic" 267 "Marezine"
                       322 "Methamphetamine (speed or ice or crank)"
                       339 "Amphetamines (speed generically)"
                       501 "Gasoline or lighter fluids"
                       509 "Corr flds, degreasers, cleaning flds, Liquid Paper"
                       601 "see also 618" 602 "Peyote"
                       604 "Psilocybin (mushrooms)" 606 "sic"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 609 "sic"
                       614 "MDA" 616 "DMT" 617 "Morning glory seeds"
                       618 "see also 601" 622 "Microdot(s), purple microdot"
                       625 "Window pane" 628 "Hawaiian rosebud seed tea"
                       636 "STP" 646 "sic" 649 "sic" 653 "Cricketshit"
                       654 "Eve" 657 "Orange barrel" 658 "Special"
                       659 "Boat (Marijuana & PCP)" 660 "Toad, Toad licking"
                       661 "sic" 662 "Kanepolin" 702 "Heroin" 703 "Opium"
                       802 "THC, cannabinol" 803 "sic"
                       981 "NEVER USED HALLUCINOGENS Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HALNEWB   328 "Pink hearts" 348 "Crystal" 601 "see also 618"
                       616 "DMT"
                       624 "Orange sunshine, sunshine, yellow sunshine"
                       636 "STP" 646 "sic" 655 "Flying elephant"
                       658 "Special" 864 "Dramamine ,Motion sickness pill"
                       981 "NEVER USED HALLUCINOGENS Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HALNEWC   625 "Window pane"
                       652 "ALD-52, ALD-S2 (version of LSD)" 656 "Mars"
                       981 "NEVER USED HALLUCINOGENS Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HALNEWD   981 "NEVER USED HALLUCINOGENS Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HALNEWE   981 "NEVER USED HALLUCINOGENS Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HALNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALDKNAM  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALLOPP
                       981 "NEVER HAD A CHANCE TO TRY HALLUCINOGENS Logic.asgn"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER HAD A CHANCE TO TRY HALLUCINOGENS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HALLAGE   981 "NEVER USED HALLUCINOGENS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HALLTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALLREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HAL30USE  81 "NEVER USED HALLUCINOGENS Logically assigned"
                       83 "DID NOT USE HALLUCINOGENS PST 30 DAYS Logic.assgnd"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 30 DAYS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 days a year)"
                       5 "1 to 2 times a month (12 to 24 days a year)"
                       6 "Every other month or so (6 to 11 days a year)"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       83 "DID NOT USE HALLUCINOGENS PST 12 MOS. Logic.assgnd"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PCPREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED PCP Logically assigned"
                       91 "NEVER USED PCP" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define HEROPP    981 "NEVER HAD A CHANCE TO TRY HEROIN Logic.assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER HAD A CHANCE TO TRY HEROIN" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HERAGE    981 "NEVER USED HEROIN Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED HEROIN" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HERTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HER30USE  81 "NEVER USED HEROIN Logically assigned"
                       83 "DID NOT USE HEROIN PAST 30 DAYS Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN THE PAST 30 DAYS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERNEEDL  1 "Yes, have used heroin with a needle"
                       2 "No, have used heroin, but not with a needle"
                       3 "Yes, used heroin w/a needle LOGICALLY IMPUTED"
                       4 "No, used heroin, but w/o a needle LOGIC. IMPUTED"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HRNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED HEROIN Logically assigned"
                       83 "NEVER USED HEROIN WITH A NEEDLE Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "NEVER USED HEROIN WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERSMOKE  1 "Yes, have smoked heroin"
                       2 "No, have used heroin, but have never smoked it"
                       3 "Yes, have smoked heroin LOGICALLY IMPUTED"
                       4 "No, used heroin, but never smoked it LOGIC.IMPUTED"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HRSMKREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       81 "NEVER USED HEROIN Logically assigned"
                       83 "USED HEROIN IN LIFE/NEVER SMOKED Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN IN LIFE BUT NEVER SMOKED IT"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERSNIFF  1 "Yes, have sniffed (snorted) heroin"
                       2 "No, have used heroin, but have never sniffed it"
                       3 "Yes, have sniffed (snorted) heroin LOGIC.IMPUTED"
                       4 "No, used heroin, but never sniffed LOGIC. IMPUTED"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HRSNFREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED HEROIN Logically assigned"
                       83 "USED HEROIN IN LIFE/NEVER SNIFFED Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN IN LIFE BUT NEVER SNIFFED IT"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DRGREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define CDCIG     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDALC     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDSED     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDTRAN    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDSTM     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDANAL    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDMJ      1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDINH     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDCOC     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDHALL    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDHER     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDOTHOP   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDNONE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDCIG    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned (CDCIG > 1)"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDALC    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned (CDALC > 1)"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDSED    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDTRAN   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDSTM    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDANAL   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDMJ     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned (CDMJ > 1)"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDINH    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDCOC    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDHALL   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDHER    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDOTHOP  1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDNONE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFCIG    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFALC    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFSED    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFTRAN   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFSTM    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFANAL   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFMJ     1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFINH    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFCOC    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFHALL   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFHER    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFOTHOP  1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFNONE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYCIG   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYALC   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYSED   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYTRAN  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYSTM   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYANAL  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYMJ    1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYINH   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYCOC   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYHALL  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYHER   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYOTH   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYNONE  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPCIG    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPALC    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPSED    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPTRAN   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPSTM    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPANAL   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPMJ     1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPINH    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPCOC    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPHALL   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPHER    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPOTHOP  1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug used pastyr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPNONE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSCIG     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSALC     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSSED     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSTRAN    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSSTM     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSANAL    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSMJ      1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSINH     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSCOC     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSHALL    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSHER     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSOTHOP   1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSNONE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NDLREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define GNNDLLIF  1 "Yes, have used a needle to take a drug"
                       2 "No, have never used a needle to take a drug"
                       3 "Yes, have used a ndle to take a drug LOGIC.IMPUTED"
                       4 "No, have never used a ndle to take drug, LOGIC. IM"
                       81 "NEVER USED A NEEDLE TO TAKE A DRUG Logic.assigned"
                       91 "NEVER USED A NEEDLE TO TAKE A DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ANY DRUG FOR NONMDCL RSN Logic.assigned"
                       83 "NEVER USED A NDL TO TAKE ANY DRUG Logic. assigned"
                       91 "NEVER USED ANY DRUG FOR NONMEDICAL REASONS"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLSED  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLTRA  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLSTM  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm STNDLREC)"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLANL  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLINH  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLCOC  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm CONDLREC)"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLHAL  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLHER  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm HRNDLREC)"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLOPT  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLSTR  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LSTD ABOVE Logically assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLNON  2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic.assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLSH1  1 "Yes, have used a needle after someone else used it"
                       2 "No, have not used a needle after someone used it"
                       81 "NEVER USED ANY DRUG Logically assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUG"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLSH2  1 "Yes, someone used a needle after I used it"
                       2 "No, no one has used a needle after I used it"
                       81 "NEVER USED ANY DRUG Logically assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic. assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUG"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SPTREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       98 "BLANK (NO ANSWER)" ;
label define DRUGTEST  1 "Yes" 2 "No"
                       3 "Did not have a job during past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TESTPOS   1 "Yes" 2 "No"
                       3 "Did not receive test in past 12 months"
                       4 "Did not have a job during past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ICELIFE   1 "Yes" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED ICE Logically assigned"
                       91 "NEVER USED ICE" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ICEREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ICE Logically assigned"
                       91 "NEVER USED ICE" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STEROPP
                       981 "NEVER HAD CHANCE TO TRY ANABOLIC STEROIDS Log.asn"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER HAD A CHANCE TO TRY ANABOLIC STEROIDS"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define STERAGE   981 "NEVER USED ANABOLIC STEROIDS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ANABOLIC STEROIDS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define STERTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED ANABOLIC STEROIDS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANABOLIC STEROIDS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STERREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ANABOLIC STEROIDS Logically assigned"
                       91 "NEVER USED ANABOLIC STEROIDS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SPNEWA    0 "None (code used only for question SP-9)"
                       116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       142 "Belladona"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       240 "Lithium carbonate"
                       322 "Methamphetamine (speed or ice or crank)"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 375 "sic"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       415 "Codeine"
                       434 "Co-Gesic, Hydrocodone, Tussionex, Vicodin"
                       438 "Anaprox, Naprosyn" 516 "Freon" 601 "see also 618"
                       604 "Psilocybin (mushrooms)" 606 "sic" 611 "Greens"
                       636 "STP" 654 "Eve" 658 "Special"
                       660 "Toad, Toad licking" 703 "Opium"
                       705 "Speed Ball (heroin + cocaine)" 803 "sic"
                       804 "Hashish" 805 "Cocaine, coke, coca"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       824 "Steroids" 828 "Tetracycline" 832 "Primo"
                       844 "Blood pressure medication" 857 "sic" 859 "sic"
                       866 "Boomers" 867 "Boron" 868 "sic" 872 "sic"
                       873 "Contraceptives, Ferutal, Ortho Novum" 880 "Frios"
                       881 "YLOALE"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SPNEWB    239 "see also 228"
                       322 "Methamphetamine (speed or ice or crank)"
                       332 "see also 346"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 456 "see also 434"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 616 "DMT"
                       803 "sic" 805 "Cocaine, coke, coca"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       824 "Steroids" 852 "sic" 871 "sic" 876 "Glass"
                       878 "Friying"
                       900 "Non-Drug reason given for Drug Problem"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SPNEWC    355 "Crystal meth" 406 "Oxycodone, Percodan, Roxicet"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)"
                       652 "ALD-52, ALD-S2 (version of LSD)" 803 "sic"
                       804 "Hashish"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SPNEWD    806 "Crack, rock" 879 "Dimethyltriptamide MMPT"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SPNEWE    701 "OTHER Opiates, NOT SPECIFIED" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define BOOKED    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NOBOOKYR  0 "Was not arrested and booked in past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BKLARCNY  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKBURGL   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKAGASLT  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKSMASLT  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKMVTHFT  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKROB     1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKRAPE    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKMURDER  2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKARSON   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKDRVINF  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKDRUNK   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKDRUG    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKPROS    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKVANDAL  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define BKOTHOFF  1 "Larceny or theft"
                       2 "Burglary or breaking and entering"
                       3 "Aggravated assault"
                       4 "Other assault, such as simple assault or battery"
                       6 "Robbery"
                       8 "Murder, homicide, or nonnegligent manslaughter"
                       10 "Driving under the influence"
                       11 "Drunkenness or other liquor law violation"
                       12 "Possession or sale of drugs"
                       14 "Oth proprty offns:- fraud, poss stln goods, vndlsm"
                       15 "Other offenses (NOT SPECIFIED)"
                       16 "Weapons offenses"
                       17 "Other offenses against persons"
                       18 "Violation of court order, parole, probation"
                       19 "Public order offenses"
                       20 "Juvenile status offenses" 22 "Traffic violations"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NOTBKED   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWERED" ;
label define PROBATON  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PAROLE    1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STRSTEAL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHSTEAL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DAMAGE    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CARSTEAL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FORCEMON  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BREAKIN   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PHYFIGHT  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HURTBAD   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GUNMONEY  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DRUNKDRV  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SOLDDRUG  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHDOING  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTHDOSP1  1 "Shoplifting" 2 "Other larceny or theft"
                       3 "Property damage/destruction (incl. vandalism)"
                       4 "Motor vehicle theft" 5 "Robbery"
                       6 "Breaking and entering"
                       7 "Hitting someone or physically fighting"
                       8 "Hurting someone enough to need medical attn"
                       9 "Other assault, battery"
                       10 "Driving under the influence of alcohol or drugs"
                       11 "Selling illegal drugs"
                       12 "Drug offense (except sales) involving marijuana"
                       13 "Other drug-related offenses"
                       14 "Drunkenness or other liquor law violation"
                       17 "Other offenses against persons" 18 "Arson"
                       19 "Nondestructive prop offenses, fraud, stln goods"
                       20 "Prostitution of commercialized sex"
                       21 "Weapons offenses"
                       22 "Violation of court order, parole, probation"
                       23 "Public order offenses"
                       24 "Juvenile status offenses" 26 "Traffic violations"
                       27 "Other offenses, NOT SPECIFIED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHDOSP2  1 "Shoplifting" 2 "Other larceny or theft"
                       3 "Property damage/destruction (incl. vandalism)"
                       4 "Motor vehicle theft"
                       7 "Hitting someone or physically fighting"
                       8 "Hurting someone enough to need medical attn"
                       9 "Other assault, battery"
                       10 "Driving under the influence of alcohol or drugs"
                       11 "Selling illegal drugs"
                       12 "Drug offense (except sales) involving marijuana"
                       13 "Other drug-related offenses"
                       14 "Drunkenness or other liquor law violation"
                       18 "Arson"
                       19 "Nondestructive prop offenses, fraud, stln goods"
                       21 "Weapons offenses" 23 "Public order offenses"
                       24 "Juvenile status offenses" 26 "Traffic violations"
                       27 "Other offenses, NOT SPECIFIED"
                       85 "BAD DATA Logically assigned"
                       98 "BLANK (NO ANSWER)" ;
label define DEXREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define NOBOOZYR  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" ;
label define ALCAGGR   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCARGUM  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCABSNT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCHIGH   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCJOB    1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCMATCD  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCRELCD  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCFRDCD  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCTOSS   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCHOLIC  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCDRUNK  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCINTOX  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCREM    1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCQUICK  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCMORN   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCSHOOK  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCALONE  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCBRKPM  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCMJ     1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "RESPONSE NOT CIRCLED" 99 "LEGITIMATE SKIP" ;
label define ALCCOC    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "RESPONSE NOT CIRCLED" 99 "LEGITIMATE SKIP" ;
label define ALCOPT    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "RESPONSE NOT CIRCLED" 99 "LEGITIMATE SKIP" ;
label define ALCHAL    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "RESPONSE NOT CIRCLED" 99 "LEGITIMATE SKIP" ;
label define ALCINH    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "RESPONSE NOT CIRCLED"
                       99 "LEGITIMATE SKIP" ;
label define ALCANAL   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "RESPONSE NOT CIRCLED" 99 "LEGITIMATE SKIP" ;
label define ALCTRAN   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "RESPONSE NOT CIRCLED" 99 "LEGITIMATE SKIP" ;
label define ALCSTM    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "RESPONSE NOT CIRCLED" 99 "LEGITIMATE SKIP" ;
label define ALCSED    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "RESPONSE NOT CIRCLED" 99 "LEGITIMATE SKIP" ;
label define AS13NONE  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" ;
label define DRDEPRSS  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEPDRG1A  116 "Methaqualone, Quaalude, Sopor" 201 "Valium"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 312 "Ionamin" 313 "Fastin, Phentermine"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 375 "sic"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       501 "Gasoline or lighter fluids" 502 "Spray paints"
                       510 "OTHER Inhalant, NOT SPECIFIED" 557 "Hagwash"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 606 "sic"
                       702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       804 "Hashish" 805 "Cocaine, coke, coca"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       808 "All of the ones I've tried" 809 "Pills"
                       810 "Hemp" 812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       869 "sic" 874 "Premarin"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG2A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       840 "Cough medicine (contents not specified)"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG3A  339 "Amphetamines (speed generically)"
                       510 "OTHER Inhalant, NOT SPECIFIED" 601 "see also 618"
                       604 "Psilocybin (mushrooms)" 803 "sic" 804 "Hashish"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG4A  415 "Codeine" 601 "see also 618"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define DEPDRG5A  607 "OTHER Hallucinogen, NOT SPECIFIED"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRARGUM   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ARGDRG1A  209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 415 "Codeine" 440 "Soma"
                       557 "Hagwash" 601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       804 "Hashish" 805 "Cocaine, coke, coca"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       808 "All of the ones I've tried" 810 "Hemp"
                       812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       818 "Nicotine" 824 "Steroids"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG2A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       332 "see also 346"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       408 "Dilaudid" 601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       840 "Cough medicine (contents not specified)"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG3A  601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG4A  508 "Nitrous oxide, whippets, dentist gas"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG5A  994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRALONE   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALNDRG1A  201 "Valium" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED" 241 "Prozac"
                       312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 401 "Darvon"
                       406 "Oxycodone, Percodan, Roxicet" 408 "Dilaudid"
                       601 "see also 618" 604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 707 "Black Tar"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke, coca" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       808 "All of the ones I've tried" 809 "Pills"
                       812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALNDRG2A  209 "Xanax"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       434 "Co-Gesic, Hydrocodone, Tussionex, Vicodin"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       840 "Cough medicine (contents not specified)"
                       848 "Liquid vitamin"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALNDRG3A  803 "sic" 805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALNDRG4A  510 "OTHER Inhalant, NOT SPECIFIED"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define ALNDRG5A  607 "OTHER Hallucinogen, NOT SPECIFIED"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRANX     1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANXDRG1A  209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 247 "Adapin, Doxepin, Sinequan"
                       271 "Zoloft" 301 "Dexedrine" 309 "Didrex"
                       312 "Ionamin" 313 "Fastin, Phentermine"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       332 "see also 346" 336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       354 "Vivarin" 355 "Crystal meth" 375 "sic"
                       408 "Dilaudid" 415 "Codeine"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       435 "Tylenol, Tylenol Extrastrength"
                       510 "OTHER Inhalant, NOT SPECIFIED" 557 "Hagwash"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 606 "sic"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       804 "Hashish" 805 "Cocaine, coke, coca"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       808 "All of the ones I've tried" 812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       814 "Caffeine" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       818 "Nicotine"
                       873 "Contraceptives, Ferutal, Ortho Novum"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG2A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 601 "see also 618"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       840 "Cough medicine (contents not specified)"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG3A  326 "White cross" 702 "Heroin" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG4A  510 "OTHER Inhalant, NOT SPECIFIED"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define ANXDRG5A  607 "OTHER Hallucinogen, NOT SPECIFIED"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRHEALTH  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLTDRG1A  209 "Xanax" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 362 "Benadryl" 408 "Dilaudid"
                       501 "Gasoline or lighter fluids" 557 "Hagwash"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)"
                       639 "Cloves, Nutmeg" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke, coca" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills" 812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       818 "Nicotine" 870 "sic"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       992 "ILLEGIBLE" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define HLTDRG2A  332 "see also 346"
                       339 "Amphetamines (speed generically)"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       506 "Amyl nitrite, poppers, locker rm odorizer,rush"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke, coca" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       814 "Caffeine" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       865 "Diuretics, Water pills"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG3A  339 "Amphetamines (speed generically)" 348 "Crystal"
                       702 "Heroin" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG4A  807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG5A  994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRNTHINK  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NTKDRG1A  116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 247 "Adapin, Doxepin, Sinequan"
                       271 "Zoloft" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       354 "Vivarin" 355 "Crystal meth" 401 "Darvon"
                       407 "Demerol" 408 "Dilaudid"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       418 "Methadone" 501 "Gasoline or lighter fluids"
                       502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 609 "sic"
                       702 "Heroin" 704 "Dope"
                       705 "Speed Ball (heroin + cocaine)"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       804 "Hashish" 805 "Cocaine, coke, coca"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       810 "Hemp" 812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       815 "Coffee" 823 "sic"
                       840 "Cough medicine (contents not specified)"
                       873 "Contraceptives, Ferutal, Ortho Novum"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG2A  322 "Methamphetamine (speed or ice or crank)"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       407 "Demerol" 420 "OTHER Analgesic, NOT SPECIFIED"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       506 "Amyl nitrite, poppers, locker rm odorizer,rush"
                       508 "Nitrous oxide, whippets, dentist gas"
                       510 "OTHER Inhalant, NOT SPECIFIED" 601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG3A  324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)"
                       601 "see also 618" 602 "Peyote"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG4A  415 "Codeine" 510 "OTHER Inhalant, NOT SPECIFIED"
                       803 "sic" 805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG5A  201 "Valium" 607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "sic" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define DRUPSET   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define UPSDRG1A  209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       332 "see also 346"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 406 "Oxycodone, Percodan, Roxicet"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       434 "Co-Gesic, Hydrocodone, Tussionex, Vicodin"
                       510 "OTHER Inhalant, NOT SPECIFIED" 601 "see also 618"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke, coca" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       808 "All of the ones I've tried" 810 "Hemp"
                       812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       814 "Caffeine" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       818 "Nicotine" 824 "Steroids"
                       840 "Cough medicine (contents not specified)"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG2A  324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 408 "Dilaudid"
                       434 "Co-Gesic, Hydrocodone, Tussionex, Vicodin"
                       508 "Nitrous oxide, whippets, dentist gas"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills" 811 "Muscle relaxers"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       814 "Caffeine" 815 "Coffee"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG3A  437 "Parafon Forte" 601 "see also 618"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG4A  510 "OTHER Inhalant, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG5A  607 "OTHER Hallucinogen, NOT SPECIFIED"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRLSWORK  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LSWDRG1A  201 "Valium" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 406 "Oxycodone, Percodan, Roxicet"
                       501 "Gasoline or lighter fluids"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       804 "Hashish" 805 "Cocaine, coke, coca"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       810 "Hemp" 812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       815 "Coffee"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LSWDRG2A  408 "Dilaudid"
                       508 "Nitrous oxide, whippets, dentist gas"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       840 "Cough medicine (contents not specified)"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LSWDRG3A  339 "Amphetamines (speed generically)"
                       605 "PCP (angel dust, phencyclidine)" 803 "sic"
                       804 "Hashish"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LSWDRG4A  510 "OTHER Inhalant, NOT SPECIFIED"
                       805 "Cocaine, coke" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define LSWDRG5A  607 "OTHER Hallucinogen, NOT SPECIFIED"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRSUSPIC  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SSPDRG1A  312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       707 "Black Tar" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coke, coca"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       840 "Cough medicine (contents not specified)"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SSPDRG2A  322 "Methamphetamine (speed or ice or crank)"
                       408 "Dilaudid" 601 "see also 618"
                       604 "Psilocybin (mushrooms)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SSPDRG3A  339 "Amphetamines (speed generically)" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SSPDRG4A  510 "OTHER Inhalant, NOT SPECIFIED"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SSPDRG5A  607 "OTHER Hallucinogen, NOT SPECIFIED"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRCOPE    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CPEDRG1A  209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke, coca" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills" 812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       818 "Nicotine" 824 "Steroids" 877 "Methazolamide"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG2A  239 "see also 228" 408 "Dilaudid" 601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG3A  339 "Amphetamines (speed generically)" 803 "sic"
                       804 "Hashish" 805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG4A  510 "OTHER Inhalant, NOT SPECIFIED" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG5A  607 "OTHER Hallucinogen, NOT SPECIFIED"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DREMGMED  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define EMDRG1A   108 "Nembutal" 209 "Xanax" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       430 "Aspirin, Ecotrin, Empirin"
                       435 "Tylenol, Tylenol Extrastrength"
                       503 "Other aerosol sprays" 601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 606 "sic"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       815 "Coffee" 858 "Antibiotic"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG2A   339 "Amphetamines (speed generically)"
                       420 "OTHER Analgesic, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG3A
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG4A   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG5A   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRTRMT    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TMTDRG1A  312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       415 "Codeine"
                       434 "Co-Gesic, Hydrocodone, Tussionex, Vicodin"
                       435 "Tylenol, Tylenol Extrastrength"
                       510 "OTHER Inhalant, NOT SPECIFIED" 601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       808 "All of the ones I've tried" 809 "Pills"
                       812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       818 "Nicotine"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TMTDRG2A  332 "see also 346"
                       339 "Amphetamines (speed generically)" 408 "Dilaudid"
                       417 "Morphine" 605 "PCP (angel dust, phencyclidine)"
                       803 "sic" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TMTDRG3A  702 "Heroin" 805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TMTDRG4A  807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TMTDRG5A  994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRDRVUN   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DRVDRG1A  110 "Tuinal" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       348 "Crystal" 601 "see also 618"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       808 "All of the ones I've tried" 812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRVDRG2A  322 "Methamphetamine (speed or ice or crank)"
                       408 "Dilaudid" 601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRVDRG3A  601 "see also 618"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRVDRG4A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       804 "Hashish" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define DRVDRG5A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TMTREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define EMPDRUG   1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGHELP   1 "Yes" 2 "No"
                       81 "NEVER SMOKED CIGARETTES Logically Assigned"
                       91 "NEVER SMOKED CIGARETTES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DRNKHELP  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       91 "NEVER USED ALCOHOL" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRMTHELP  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass."
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTEMRG  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass."
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTHOSP  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass."
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTDOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass."
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTTRMT  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass."
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTMHC   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass."
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTSHG   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass."
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTSOP   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass."
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTSP    4 "AA or NA or CA" 5 "Residential placement"
                       9 "Within myself (self-treatment)"
                       10 "Church or religious influence" 12 "Friends"
                       13 "Court or correctional facilities"
                       14 "Counselor, therapist, psychologist" 15 "School"
                       16 "Home, family" 22 "Hospital"
                       24 "Drug treatment or rehab. center"
                       25 "Mental health center" 26 "Self-help group"
                       81 "NEVER USED DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTREC   1 "Within the past month"
                       2 "More than one month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       8 "Received treatment in past year LOGICALLY IMPUTED"
                       9 "Received treatment in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS Lg.ass."
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRUGS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NRTXLIFE  0 "NONE" 985 "BAD DATA Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define NOTRMT    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TXEMRG    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXHOSP    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXDOC     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXTRMT    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXMHC     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXSHG     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXSOP     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXSP      4 "AA or NA or CA" 5 "Residential placement"
                       9 "Within myself (self-treatment)"
                       10 "Church or religious influence" 12 "Friends"
                       13 "Court or correctional facilities"
                       14 "Counselor, therapist, psychologist" 15 "School"
                       16 "Home, family"
                       17 "Employer's hotline, job corps, on the job"
                       22 "Hospital" 24 "Drug treatment or rehab. center"
                       25 "Mental health center"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRMTLIFE  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTRESP  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTFEAR  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTCOST  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTEVNT  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTPR    1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTHLTH  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTJOB   1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTJAIL  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTSERV  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTBQD   1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTDNA   1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTSOR   1 "Very important" 2 "Somewhat important"
                       3 "Not at all important" 4 "Response circled only"
                       5 "Reason specified but no ranking"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTRSP   1 "Wanted to change lifestyle"
                       2 "Had family responsibilities"
                       5 "Occurrence of a signif. personal or special event"
                       6 "Pressure from family (or close friends)"
                       7 "Had concerns about health"
                       8 "Had concerns about job" 9 "Sent to jail"
                       14 "Depression"
                       15 "Fear of dying/suicide(fear of, or attempted)"
                       16 "Church or other religious influence"
                       17 "Forced/compelled (but by whom is unknown)"
                       18 "Wanted to quit drugs"
                       19 "Reason connected to the military" 20 "Overdose"
                       21 "Loss of control/dependency"
                       22 "Felt bad about self/wanted to do or be better"
                       23 "Reason connected to driver's license"
                       25 "Committing violence"
                       26 "Pressure from counselor/soc. srvcs/etc."
                       27 "Psychological disorders"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTDRGA  108 "Nembutal" 116 "Methaqualone, Quaalude, Sopor"
                       118 "Pentobarbital, pentothal, sodium pentothal"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 202 "Librium" 204 "Menrium"
                       228 "see also 239" 241 "Prozac"
                       247 "Adapin, Doxepin, Sinequan" 319 "Cylert"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 401 "Darvon"
                       406 "Oxycodone, Percodan, Roxicet" 408 "Dilaudid"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       417 "Morphine" 418 "Methadone"
                       430 "Aspirin, Ecotrin, Empirin"
                       434 "Co-Gesic, Hydrocodone, Tussionex, Vicodin"
                       435 "Tylenol, Tylenol Extrastrength"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       510 "OTHER Inhalant, NOT SPECIFIED" 601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke, coca" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       808 "All of the ones I've tried" 809 "Pills"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       824 "Steroids"
                       840 "Cough medicine (contents not specified)"
                       875 "Buds" 900 "Not a drug"
                       989 "LEGITIMATE SKIP Logically assigned"
                       992 "Illegible" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TRMTDRGB  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or crank)"
                       415 "Codeine" 423 "Percocet" 427 "Darvocet"
                       601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       804 "Hashish" 805 "Cocaine, coke, coca"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       900 "Not a drug"
                       989 "LEGITIMATE SKIP Logically assigned" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define TRMTDRGC  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       246 "Clonopin, Klonopin" 355 "Crystal meth"
                       601 "see also 618" 805 "Cocaine, coke, coca"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       989 "LEGITIMATE SKIP Logically assigned" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define TRMTDRGD  605 "PCP (angel dust, phencyclidine)"
                       989 "LEGITIMATE SKIP Logically assigned" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define TRMTDRGE  989 "LEGITIMATE SKIP Logically assigned" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define TRMTOUTC  1 "Still in treatment"
                       2 "Successfully completed treatment"
                       3 "Had a problem with program"
                       4 "Couldn't afford to continue treatment"
                       5 "Family needed me" 6 "Began using drug(s) again"
                       7 "Other outcome, not specified"
                       8 "Didn't need treatment"
                       10 "Successful because of own efforts, not trmt."
                       11 "Use to a lesser extent"
                       14 "Successful because of religious reasons"
                       15 "Discontinued treatment, success unknown"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TMTPHI    1 "Response circled" 2 "Response not circled"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TMTPSAVE  1 "Response circled" 2 "Response not circled"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TMTPFMLY  1 "Response circled" 2 "Response not circled"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TMTPEMPR  1 "Response circled" 2 "Response not circled"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TMTPMEDI  1 "Response circled" 2 "Response not circled"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TMTPFREE  1 "Response circled" 2 "Response not circled"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TMTPOTH   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TMTPASP   1 "Health Insurance" 2 "Own savings or earnings"
                       3 "Family member" 4 "Employer or union"
                       5 "Medicare or Medicaid" 6 "Free"
                       9 "State/city public assistance/welfare/relief"
                       10 "Court" 12 "School" 13 "Hospital"
                       14 "Veterans Administration/military services"
                       15 "Treatment program"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define RSKPKCIG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKTRYMJ  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKMJOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKMJREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKTRYPCP  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKPCPREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKTRYHER  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKHERREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKTRYCOC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCOCOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCOCREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCRKOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKANSOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKANSREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RK2DRINK  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RK5DRINK  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKBINGE  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKDIFMJ  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFLSD  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFPCP  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFCOC  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFHER  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKSELL   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKNEIDRN  1 "Often" 2 "Occasionally" 3 "Rarely" 4 "Never"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKNEISEL  1 "Often" 2 "Occasionally" 3 "Rarely" 4 "Never"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HIGHBP    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BPMED     1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WALKPAIN  1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TIMEPAIN  1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define UPSHOR    1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ASTHMA    1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRPSYCH   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HEART     1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FLU       1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALLERG    1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HOSPYR    1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SOREYR    1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RUNNYYR   1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COUGHYR   1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PHLEGMYR  1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HEALTHYR  1 "Excellent" 2 "Very good" 3 "Good" 4 "Fair" 5 "Poor"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTEAT    1 "Rarely or none of the time (less than a day)"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time (3-4 days)"
                       4 "Most or all of the time (5-7 days)"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTMIND   1 "Rarely or none of the time (less than a day)"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time (3-4 days)"
                       4 "Most or all of the time (5-7 days)" 94 "DON'T KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTDEPRS  1 "Rarely or none of the time (less than a day)"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time (3-4 days)"
                       4 "Most or all of the time (5-7 days)" 94 "DON'T KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTEFFRT  1 "Rarely or none of the time (less than a day)"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time (3-4 days)"
                       4 "Most or all of the time (5-7 days)" 94 "DON'T KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTSLEEP  1 "Rarely or none of the time (less than a day)"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time (3-4 days)"
                       4 "Most or all of the time (5-7 days)" 94 "DON'T KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTSAD    1 "Rarely or none of the time (less than a day)"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time (3-4 days)"
                       4 "Most or all of the time (5-7 days)" 94 "DON'T KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTGOING  1 "Rarely or none of the time (less than a day)"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time (3-4 days)"
                       4 "Most or all of the time (5-7 days)" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MARITAL   1 "Married" 2 "Widowed" 3 "Divorced or separated"
                       4 "Has never married" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NOMARR    85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKSTAT  1 "Working full-time, 35 hours or more a week"
                       2 "Working part-time, less than 35 hours a week"
                       3 "Have job but out: illness/leave/furlough/strike"
                       4 "Unemployed or laid off and looking for work"
                       5 "Unemployed and not looking for work"
                       6 "Full-time homemaker only" 7 "In school only"
                       8 "Retired" 9 "Disabled, not able to work"
                       21 "Working full time, 35 hours or more a week"
                       22 "Working part time, less than 35 hours a week"
                       23 "Have a job but out: illness/leave/furlough/strike"
                       24 "Unemployed or laid off and looking for work"
                       25 "Unemployed and not looking for work"
                       26 "Full-time homemaker" 27 "In school only"
                       28 "Retired" 29 "Disabled, not able to work"
                       30 "Other, in labor force"
                       31 "Other, not in the labor force"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PAYMO     89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER WORKED FOR PAY" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PAYYR     985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER WORKED FOR PAY" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NO5JOB    94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORKDAYS  89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORKBLAH  89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CWE       1 "Respondent" 2 "Someone else (see CWESCs)"
                       3 "Income contributed equally by R and (see CWESCs)"
                       4 "No one"
                       6 "Some one else (see CWESCs) LOGICALLY ASSIGNED"
                       7 "Inc. from R & other(s) equally (see CWESCs) LOG AS"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CWESC1    9 "Head of Household" 10 "Spouse" 20 "Parent/Guardian"
                       50 "Grandparent/Great+ Grandparent"
                       60 "Live-In Partner" 61 "Friend/Roommate/Companion"
                       71 "Cousin" 85 "Landlord/Home Owner"
                       91 "Other Non-Relative, Gender not specified"
                       92 "Other, Relation and Gender Unspecified"
                       109 "Male Head of Household" 110 "Husband"
                       111 "Ex-Husband" 120 "Father/Male Guardian"
                       121 "Step/Adopted/Foster Father"
                       122 "Father In-Law/Step Father In-Law" 130 "Son"
                       132 "Son In-Law" 133 "Grandson"
                       140 "Brother/Half Brother"
                       141 "Step/Adopted/Foster Brother" 142 "Brother In-Law"
                       150 "Grandfather/Great+ Grandfather"
                       160 "Male Live-In Partner"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       170 "Uncle" 171 "Male Cousin"
                       181 "Other Male God Relative"
                       190 "Other Male Relative"
                       191 "Other Male Non-Relative"
                       192 "Other Male, Relation Unspecified" 210 "Wife"
                       220 "Mother/Female Guardian"
                       221 "Step/Adopted/Foster Mother"
                       222 "Mother In-Law/Step Mother In-Law" 230 "Daughter"
                       231 "Step/Adopted/Foster Daughter"
                       232 "Daughter In-Law" 240 "Sister/Half Sister"
                       241 "Step/Adopted/Foster Sister" 242 "Sister In-Law"
                       250 "Grandmother/Great+ Grandmother"
                       260 "Female Live-In Partner"
                       261 "Female Fiancee/Girlfriend/Roommate/Companion"
                       270 "Aunt" 271 "Female Cousin" 272 "Niece"
                       285 "Female Landlord/Home Owner"
                       291 "Other Female Non-Relative"
                       292 "Other Female, Relation Unspecified" 315 "In-Laws"
                       320 "Parents/Guardians"
                       350 "Grandparents/Great+ Grandparents"
                       361 "Friends/Roommates/Companions" 371 "Cousins"
                       390 "Other Relatives, Gender not specified"
                       392 "Others, Relation and Gender Unspecified"
                       430 "Sons" 442 "Brothers In-Law"
                       540 "Sisters/Half Sisters"
                       985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CWESC2    20 "Parent/Guardian" 60 "Live-In Partner"
                       61 "Friend/Roommate/Companion"
                       92 "Other, Relation and Gender Unspecified"
                       110 "Husband" 120 "Father/Male Guardian"
                       121 "Step/Adopted/Foster Father"
                       140 "Brother/Half Brother" 142 "Brother In-Law"
                       150 "Grandfather/Great+ Grandfather"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       170 "Uncle" 191 "Other Male Non-Relative" 210 "Wife"
                       220 "Mother/Female Guardian"
                       221 "Step/Adopted/Foster Mother" 230 "Daughter"
                       240 "Sister/Half Sister" 242 "Sister In-Law"
                       250 "Grandmother/Great+ Grandmother" 270 "Aunt"
                       291 "Other Female Non-Relative" 315 "In-Laws"
                       392 "Others, Relation and Gender Unspecified"
                       540 "Sisters/Half Sisters" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define FULLPART  1 "Full-time" 2 "Part-time"
                       3 "Chief source of income does not work"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define EDUC      0 "No schooling" 1 "First Grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh Grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "One year college"
                       14 "2 years college" 15 "3 years college"
                       16 "4 years college" 17 "Graduate/professional school"
                       98 "BLANK (NO ANSWER)" ;
label define GRADHS    1 "Yes" 2 "No" 4 "No LOGICALLY IMPUTED (from DIPLOMA)"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DIPLOMA   1 "High school diploma" 2 "GED certificate"
                       3 "Neither of the above"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ENROLLD   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SCHPLANS  1 "Has plans to enroll in a school in future"
                       2 "Has completed all schooling"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define STUDENT   1 "A full-time student" 2 "A part-time student"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SCHDAYS   89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SKIPPED   89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MILES     99989 "LEGITIMATE SKIP Logically assigned"
                       99991 "HAS NEVER DRIVEN A MOTOR VEHICLE"
                       99994 "DON'T KNOW" 99997 "REFUSED"
                       99998 "BLANK (NO ANSWER)" 99999 "LEGITIMATE SKIP" ;
label define ACCID     1 "Yes" 2 "No" 3 "Did not drive in past 12 months"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TOTPEOP   97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MOTHER    0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FATHER    0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STEPMOM   0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STEPDAD   0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SPOUSE    0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INLAW     0 "None"
                       93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OWNCHILD  0 "None"
                       93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STEPCHLD  0 "None"
                       93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BROSIS    0 "None"
                       93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHREL    0 "None"
                       93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FRIENDS   0 "None"
                       93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHERNON  0 "None"
                       93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MOVDAWAY  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DORM      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define MILBASE   94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define HOSP      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define OTHGPH    85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define OTHGPHSP  1 "Own dwelling" 2 "Married"
                       3 "(Moved to)another dwelling,ownership not specified"
                       4 "(Moved to) apartment, ownership not specified"
                       7 "Foster home"
                       8 "Nursing home/home for handicapped/retirement home"
                       9 "Died" 10 "Lives out of state/city/county"
                       11 "Staying/living with a friend"
                       12 "Moved away for job or job training(incl. military)"
                       14 "Overseas/out of country"
                       15 "Lives with mother/father/relatives"
                       17 "With other children in school group housing"
                       18 "Group housing in college" 20 "Hotel"
                       21 "Group home/halfway house/shelter/tx. or rehab."
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SERVICE   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MILSTAT   2 "In a Reserves component"
                       3 "Separated/retired from Reserves or active duty"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TELNO     94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MOVES     94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NOFAMRES  0 "Some relative(s) do(es) or may reside in household"
                       1 "No relative resides in household" ;
label define PROXABLE  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PROXYREL  1 "Respondent's spouse/live-in partner"
                       2 "Respondent's father" 3 "Respondent's mother"
                       4 "Respondent's brother" 5 "Respondent's sister"
                       6 "Other family member, relation not specified"
                       20 "Parent/Guardian"
                       50 "Grandparent/Great+ Grandparent"
                       60 "Live-In Partner" 61 "Friend/Roommate/Companion"
                       71 "Cousin"
                       91 "Other Non-Relative, Gender not specified"
                       110 "Husband" 120 "Father/Male Guardian"
                       121 "Step/Adopted/Foster Father" 130 "Son"
                       132 "Son In-Law" 142 "Brother In-Law"
                       150 "Grandfather/Great+ Grandfather" 170 "Uncle"
                       210 "Wife" 220 "Mother/Female Guardian"
                       221 "Step/Adopted/Foster Mother" 230 "Daughter"
                       231 "Step/Adopted/Foster Daughter"
                       232 "Daughter In-Law" 240 "Sister/Half Sister"
                       242 "Sister In-Law"
                       250 "Grandmother/Great+ Grandmother"
                       261 "Female Fiancee/Girlfriend/Roommate/Companion"
                       270 "Aunt" 291 "Other Female Non-Relative"
                       321 "Step/Adopted/Foster Parents"
                       350 "Grandparents/Great+ Grandparents"
                       989 "LEGITIMATE SKIP Logically assigned"
                       996 "MULTIPLE RESPONSE" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define PROXHOME  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PROXJOIN  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MEDICARE  1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MEDICAID  1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CHAMPUS   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PRVHLTIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OWNHLTIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GRPHLTIN  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINALC  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINDRG  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINMNT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WHOANSHI  1 "Sample member"
                       2 "Proxy, relationship to sample member not specified"
                       10 "Spouse" 20 "Parent/Guardian"
                       50 "Grandparent/Great+ Grandparent"
                       60 "Live-In Partner" 61 "Friend/Roommate/Companion"
                       71 "Cousin"
                       91 "Other Non-Relative, Gender not specified"
                       92 "Other, Relation and Gender Unspecified"
                       110 "Husband" 120 "Father/Male Guardian"
                       121 "Step/Adopted/Foster Father" 130 "Son"
                       132 "Son In-Law" 140 "Brother/Half Brother"
                       142 "Brother In-Law"
                       150 "Grandfather/Great+ Grandfather"
                       160 "Male Live-In Partner" 170 "Uncle"
                       191 "Other Male Non-Relative" 210 "Wife"
                       220 "Mother/Female Guardian"
                       221 "Step/Adopted/Foster Mother" 230 "Daughter"
                       231 "Step/Adopted/Foster Daughter"
                       232 "Daughter In-Law" 240 "Sister/Half Sister"
                       242 "Sister In-Law"
                       250 "Grandmother/Great+ Grandmother"
                       261 "Female Fiancee/Girlfriend/Roommate/Companion"
                       270 "Aunt" 291 "Other Female Non-Relative"
                       320 "Parents/Guardians"
                       350 "Grandparents/Great+ Grandparents"
                       994 "DON'T KNOW" 996 "MULTIPLE RESPONSE" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define JOB       1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HOURS     985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define WORK      1 "Worked only for an employer"
                       2 "Was self-employed only"
                       3 "Self-employed and working for an employer"
                       4 "Did not work during the month"
                       5 "Did work during the month LOGICALLY IMPUTED"
                       6 "Did not work during the month LOGICALLY IMPUTED"
                       98 "BLANK (NO ANSWER)" ;
label define WAG1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AWAG1     999985 "BAD DATA Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define WEEKS     94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SOC1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ASOC1     999985 "BAD DATA Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define SSI1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ASSI1     999985 "BAD DATA Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define PUB1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DON'T KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AFDC1     1 "Income from AFDC/ADC" 2 "Income from other"
                       3 "Income from both" 94 "DON'T KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WEL1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AWEL1     999985 "BAD DATA Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define INT1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AINT1     999985 "BAD DATA Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define CHD1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ACHD1     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define OTH1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DON'T KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AOTH1     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define FAMLYRES  1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WAG2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AWAG2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define SOC2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ASOC2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define SSI2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ASSI2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define PUB2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AFDC2     1 "Income from AFDC/ADC" 2 "Income from other"
                       3 "Income from both"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WEL2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AWEL2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define INT2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AINT2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define CHD2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ACHD2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define OTH2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AOTH2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define WHOANSIN  1 "Sample member"
                       2 "Proxy, relationship to sample member not specified"
                       10 "Spouse" 20 "Parent/Guardian" 60 "Live-In Partner"
                       61 "Friend/Roommate/Companion" 71 "Cousin"
                       91 "Other Non-Relative, Gender not specified"
                       110 "Husband" 120 "Father/Male Guardian"
                       121 "Step/Adopted/Foster Father" 130 "Son"
                       132 "Son In-Law" 133 "Grandson"
                       140 "Brother/Half Brother" 142 "Brother In-Law"
                       150 "Grandfather/Great+ Grandfather"
                       160 "Male Live-In Partner"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       170 "Uncle" 210 "Wife" 220 "Mother/Female Guardian"
                       221 "Step/Adopted/Foster Mother"
                       222 "Mother In-Law/Step Mother In-Law" 230 "Daughter"
                       231 "Step/Adopted/Foster Daughter"
                       232 "Daughter In-Law" 240 "Sister/Half Sister"
                       242 "Sister In-Law"
                       250 "Grandmother/Great+ Grandmother"
                       261 "Female Fiancee/Girlfriend/Roommate/Companion"
                       270 "Aunt" 291 "Other Female Non-Relative"
                       320 "Parents/Guardians"
                       321 "Step/Adopted/Foster Parents"
                       350 "Grandparents/Great+ Grandparents"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 996 "MULTIPLE RESPONSE" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define FSTAMP    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DON'T KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PEOPFD    85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FOOD      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AFOOD     999985 "BAD DATA Logically assigned"
                       999994 "DON'T KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define BAP       1 "AM" 2 "PM" 98 "BLANK (NO ANSWER)" ;
label define EAP       1 "AM" 2 "PM" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define LANGVER   1 "English" 2 "Spanish" 98 "BLANK (NO ANSWER)" ;
label define UNDINT    1 "No difficulty-no language or reading problem"
                       2 "Just a little difficulty-almost no lang/readg prob"
                       3 "Fair amount of difficulty-some lang/reading prob"
                       4 "A lot of difficulty-considerable lang/reading prob"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define COOPINT   1 "Very cooperative" 2 "Fairly cooperative"
                       3 "Not very cooperative" 4 "Openly hostile"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define PRIVACY   1 "Completely private-no one present/able to overhear"
                       3 "Minor distractions"
                       5 "Person(s) in room or listening 1/3 of the time"
                       7 "Serious interruptions more than half the time"
                       9 "Constant presence of other person(s)"
                       85 "BAD DATA Logically assigned"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define PPRES     1 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define SPRES     2 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define PARPRES   3 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OARPRES   4 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OAPRES    5 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define CPRES     6 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OPRESNSP  7 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OPRESSPA  9 "Head of Household" 10 "Spouse" 20 "Parent/Guardian"
                       37 "Child, Relation Unspecified" 60 "Live-In Partner"
                       61 "Friend/Roommate/Companion" 71 "Cousin"
                       83 "Nurse/Health Care Aide/Home Care Worker"
                       84 "Neighbor/Co-Worker/Visitor"
                       85 "Landlord/Home Owner"
                       91 "Other Non-Relative, Gender not specified"
                       92 "Other, Relation and Gender Unspecified"
                       110 "Husband" 120 "Father/Male Guardian"
                       121 "Step/Adopted/Foster Father" 130 "Son"
                       131 "Step/Adopted/Foster Son"
                       140 "Brother/Half Brother"
                       141 "Step/Adopted/Foster Brother"
                       150 "Grandfather/Great+ Grandfather"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       170 "Uncle" 191 "Other Male Non-Relative"
                       192 "Other Male, Relation Unspecified" 210 "Wife"
                       220 "Mother/Female Guardian"
                       221 "Step/Adopted/Foster Mother"
                       222 "Mother In-Law/Step Mother In-Law" 230 "Daughter"
                       231 "Step/Adopted/Foster Daughter"
                       232 "Daughter In-Law" 240 "Sister/Half Sister"
                       242 "Sister In-Law"
                       250 "Grandmother/Great+ Grandmother"
                       261 "Female Fiancee/Girlfriend/Roommate/Companion"
                       270 "Aunt" 280 "Female God Child/God Daughter"
                       292 "Other Female, Relation Unspecified"
                       337 "Children, Relation Unspecified" 340 "Siblings"
                       350 "Grandparents/Great+ Grandparents"
                       361 "Friends/Roommates/Companions" 371 "Cousins"
                       384 "Neighbors/Co-Workers/Visitors"
                       390 "Other Relatives, Gender not specified"
                       391 "Other Non-Relatives, Gender not specified"
                       392 "Others, Relation and Gender Unspecified"
                       430 "Sons" 440 "Brothers/Half Brothers"
                       461 "Male Fiances/Boyfriends/Roommates/Companions"
                       492 "Other Males, Relation Unspecified"
                       540 "Sisters/Half Sisters"
                       561 "Female Fiancees/Girlfriends/Roommates/Companions"
                       900 "Not A Person" 985 "BAD DATA Logically assigned"
                       994 "DON'T KNOW" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define OPRESSPB  9 "Head of Household" 33 "Grandchild"
                       61 "Friend/Roommate/Companion" 71 "Cousin"
                       84 "Neighbor/Co-Worker/Visitor" 170 "Uncle"
                       230 "Daughter" 240 "Sister/Half Sister"
                       261 "Female Fiancee/Girlfriend/Roommate/Companion"
                       270 "Aunt" 272 "Niece"
                       292 "Other Female, Relation Unspecified"
                       330 "Own Children/Own Half Children"
                       337 "Children, Relation Unspecified"
                       384 "Neighbors/Co-Workers/Visitors"
                       390 "Other Relatives, Gender not specified"
                       392 "Others, Relation and Gender Unspecified"
                       900 "Not A Person" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define WHOMARKD  1 "Respondent marked ALL the Answer Sheet responses"
                       2 "Interviewer marked All the Answer Sheet responses"
                       3 "Combination of respondent and F.I.BLANK (NO ANSWER"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define QUARTER   1 "Quarter" 2 "Quarter" 3 "Quarter" 4 "Quarter" ;
label define FAMSKIP   0 "Respondent has other family members in household"
                       1 "Respondent didn't have other family in household"
                       98 "BLANK (NO ANSWER)" ;
label define PDEN      1 "Segment in a MSA with 1 million or more persons"
                       2 "Segment in a MSA with fewer than 1 million persons"
                       3 "Segment not in MSA" ;
label define GQTYPE    1 "Halfway House" 2 "Boarding House" 3 "College Dorm"
                       4 "Shelter" 5 "Other" 9 "Not Group Quarters" ;
label define PDEN2     1 "Segment in MSA with 1 million or more persons"
                       2 "Segm. in a MSA from 250000 to 999999 persons"
                       3 "Segment in a MSA with fewer than 250000 persons"
                       4 "Segment not in a MSA and not in a rural area"
                       5 "Segment not in a MSA and in a rural area" ;
label define DC        1 "Low SES - DC" 2 "Not Low SES - DC" 9 "NOT IN DC" ;
label define CHICAGO   1 "Low SES - CHICAGO" 2 "Not Low SES - CHICAGO"
                       9 "NOT IN CHICAGO" ;
label define DENVER    1 "Low SES - DENVER" 2 "Not Low SES - DENVER"
                       9 "NOT IN DENVER" ;
label define LA        1 "Low SES - LA" 2 "Not Low SES - LA" 9 "NOT IN LA" ;
label define MIAMI     1 "Low SES - MIAMI" 2 "Not Low SES - MIAMI"
                       9 "NOT IN MIAMI" ;
label define NEWYORK   1 "Low SES - NEW YORK" 2 "Not Low SES - NEW YORK"
                       9 "NOT IN NEW YORK" ;
label define REGION    1 "Northeast" 2 "North Central" 3 "South" 4 "West" ;
label define DIVISION  1 "New England" 2 "Middle Atlantic"
                       3 "East North Central" 4 "West North Central"
                       5 "South Atlantic" 6 "East South Central"
                       7 "West South Central" 8 "Mountain" 9 "Pacific" ;
label define CENCTY    1 "Yes" 2 "No"
                       3 "Not in any of the 6 metropolitan areas" ;
label define URBARE    1 "Yes" 2 "No"
                       3 "Not in any of the 6 metropolitan areas"
                       9 "Data suppressed for reasons of confidentiality" ;
label define METRO     1 "Chicago Metropolitan area"
                       2 "Denver Metropolitan area"
                       3 "Los Angeles Metropolitan area"
                       4 "Miami Metropolitan area"
                       5 "New York Metropolitan area"
                       6 "Washington, D.C. Metropolitan area"
                       9 "Not in any of the 6 Metropolitan areas" ;
label define CENTRALC  1 "Sample segm. within a central city of metro area"
                       2 "Sam. segm. not within a central city of metro area"
                       3 "Sample segment not within a MSA" ;
label define IIAGE     1 "Age from birthdate"
                       2 "Age from cover of questionnaire"
                       3 "Age from roster"
                       4 "Age statistically imputed using age gr from roster" ;
label define IRSEX     1 "Male" 2 "Female" ;
label define IISEX     1 "Sex from questionnaire"
                       2 "Sex from relationship on roster"
                       3 "Sex from roster" 4 "Sex statistically imputed" ;
label define IRRACE    1 "American indian or Alaskan native"
                       2 "Asian or Pacific islander" 3 "Black" 4 "White" ;
label define IIRACE    1 "Race from questionnaire"
                       2 "Race from interview observation"
                       3 "Race from roster"
                       4 "Race statis imputed using race - Other on roster"
                       5 "Race statistically imputed, no infor. from roster" ;
label define IRHOIND   1 "Hispanic" 2 "Nonhispanic" ;
label define IIHOIND   1 "Hispanicity derived from questionnaire"
                       2 "Hispanicity derived from roster" ;
label define IRHOGRP   1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       99 "LEGITIMATE SKIP" ;
label define IIHOGRP   1 "Hispanic-Origin Group taken from questionnaire"
                       3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP Respondent is not hispanic" ;
label define IRHOGRP2  1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       5 "Central American" 6 "South American" 7 "Caribbean"
                       99 "LEGITIMATE SKIP Respondent is not hispanic" ;
label define IIHOGRP2  1 "Hispanic-Origin Group taken from questionnaire"
                       3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP Respondent is not hispanic" ;
label define IRMARIT   1 "Married" 2 "Widowed" 3 "Divorced or Separated"
                       4 "Never Married" 99 "LEGITIMATE SKIP" ;
label define IIMARIT   1 "Questionnaire data"
                       2 "Logically imputed data from questionnaire"
                       4 "Logically imputed data from roster"
                       5 "Statistically imputed data"
                       6 "Logically imputed from relationship on roster"
                       9 "LEGITIMATE SKIP (less than or = 14 years old)" ;
label define IREDUC    0 "No schooling" 1 "First grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "One year of college"
                       14 "Two years of college" 15 "Three years of college"
                       16 "Four years of college"
                       17 "Graduate/professional school" ;
label define IIEDUC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRHSGRAD  1 "Yes, graduated from high school"
                       2 "No, did not graduate from high school" ;
label define IIHSGRAD  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRWORKST  1 "Working full-time, 35 hours or more a week"
                       2 "Working part-time, less than 35 hours a week"
                       3 "Have job but out: illness/leave/furlough/strike"
                       4 "Unemployed or laid off and looking for work"
                       5 "Unemployed and not looking for work"
                       6 "Full-time homemaker only" 7 "In school only"
                       8 "Retired" 9 "Disabled, not able to work"
                       10 "Other, in labor force"
                       11 "Other, not in labor force" ;
label define IIWORKST  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRPINSUR  1 "Yes, respondent does have private health insurance"
                       2 "No, respondent does not have private health insur." ;
label define IIPINSUR  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRINSUR   1 "Yes, respondent does have health insurance"
                       2 "No, respondent does not have health insurance" ;
label define IIINSUR   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRWAG1    1 "Yes" 2 "No" ;
label define IIWAG1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAWAG1   0 "Zero income received" ;
label define IIAWAG1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSOC1    1 "Yes" 2 "No" ;
label define IISOC1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRASOC1   0 "Zero income received" ;
label define IIASOC1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSSI1    1 "Yes" 2 "No" ;
label define IISSI1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRASSI1   0 "Zero income received" ;
label define IIASSI1   1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP" ;
label define IRWEL1    1 "Yes" 2 "No" ;
label define IIWEL1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAWEL1   0 "Zero income received" ;
label define IIAWEL1   1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP" ;
label define IRINT1    1 "Yes" 2 "No" ;
label define IIINT1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAINT1   0 "Zero income received" ;
label define IIAINT1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRCHD1    1 "Yes" 2 "No" ;
label define IICHD1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRACHD1   0 "Zero income received" ;
label define IIACHD1   1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP" ;
label define IROTH1    1 "Yes" 2 "No" ;
label define IIOTH1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAOTH1   0 "Zero income received" ;
label define IIAOTH1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRWAG2    1 "Yes" 2 "No" ;
label define IIWAG2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRAWAG2   0 "Zero income received" ;
label define IIAWAG2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSOC2    1 "Yes" 2 "No" ;
label define IISOC2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRASOC2   0 "Zero income received" ;
label define IIASOC2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSSI2    1 "Yes" 2 "No" ;
label define IISSI2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRASSI2   0 "Zero income received" ;
label define IIASSI2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRWEL2    1 "Yes" 2 "No" ;
label define IIWEL2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRAWEL2   0 "Zero income received" ;
label define IIAWEL2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRINT2    1 "Yes" 2 "No" ;
label define IIINT2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRAINT2   0 "Zero income received" ;
label define IIAINT2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRCHD2    1 "Yes" 2 "No" ;
label define IICHD2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRACHD2   0 "Zero income received" ;
label define IIACHD2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IROTH2    1 "Yes" 2 "No" ;
label define IIOTH2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRAOTH2   0 "Zero income received" ;
label define IIAOTH2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRFOOD    1 "Yes" 2 "No" ;
label define IIFOOD    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAFOOD   0 "Zero income received" ;
label define IIAFOOD   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRALCRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used alcohol" ;
label define IIALCRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRMJRC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 9 "Never used marijuana" ;
label define IIMJRC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCOCRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 9 "Never used cocaine" ;
label define IICOCRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSEDRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used sedatives" ;
label define IISEDRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRTRNRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used tranquilizers" ;
label define IITRNRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSTMRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used stimulants" ;
label define IISTMRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRANLRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used analgesics" ;
label define IIANLRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCIGRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never smoked cigarettes" ;
label define IICIGRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IROTBRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       9 "Never used smokeless tobacco" ;
label define IIOTBRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRINHRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 9 "Never used inhalants" ;
label define IIINHRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCRKRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 9 "Never used crack" ;
label define IICRKRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHALRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used hallucinogens" ;
label define IIHALRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHERRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used heroin" ;
label define IIHERRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRPCPRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 9 "Never used PCP" ;
label define IIPCPRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRICERC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago" 9 "Never used ice" ;
label define IIICERC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSTRRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       9 "Never used anabolic steroids" ;
label define IISTRRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRALCFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IIALCFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRMJFQ    1 "Used several times per day in past year"
                       2 "Used daily in past year"
                       3 "Used almost daily in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used several times per month in past year"
                       6 "Used 1-2 times per month in past year"
                       7 "Used every other month in past year"
                       8 "Used 3-5 times in past year"
                       9 "Used 1-2 times in past year"
                       10 "Never used or did not use in the past year" ;
label define IIMJFQ    1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRCOCFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times per month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IICOCFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSEDFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IISEDFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRTRNFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IITRNFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSTMFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IISTMFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRANLFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IIANLFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IROTBFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IIOTBFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRINHFQ   1 "Use daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IIINHFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHALFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past year" ;
label define IIHALFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define CATAGE    1 "12-17 years" 2 "18-25 years" 3 "26-34 years"
                       4 "35+ years" ;
label define CATAG2    1 "12-17 years" 2 "18-25 years" 3 "26+ years" ;
label define CATAG3    1 "12-17 years" 2 "18-25 years" 3 "26-34 years"
                       4 "35-49 years" 5 "50+ years" ;
label define RACE      1 "White (IRRACE = 4 and IRHOIND = 2)"
                       2 "Black (IRRACE = 3 and IRHOIND = 2)"
                       3 "Hispanic (IRHOIND = 1)"
                       4 "Other (IRRACE = 1-2 and IRHOIND = 2)" ;
label define HISPRACE  1 "Hispanic" 2 "Nonhispanic Black"
                       3 "Nonhispanic Nonblack" ;
label define EDUCCAT2  1 "Less than high school (IREDUC=0-11 and IRAGE=>18)"
                       2 "High school graduate (IREDUC = 12 and IRAGE=>18)"
                       3 "Some college (IREDUC = 13-15 and IRAGE => 18)"
                       4 "College graduate (IREDUC = 16-17 and IRAGE => 18)"
                       5 "12-17 year olds (IRAGE = 12-17)" ;
label define EMPSTAT2  1 "Full=time (IRWORKST =1,3 and IRAGE => 18)"
                       2 "Part-time (IRWORKST = 2 and IRAGE => 18)"
                       3 "Unemployed (IRWORKST = 4,5,10 and IRAGE => 18)"
                       4 "Other (IRWORKST = 6-9,11 and IRAGE => 18)"
                       5 "12-17 year olds (IRAGE = 12-17)" ;
label define IIINDINC  1 "All personal income sources from questionnaire"
                       3 "At least 1 of sources were stat or logic imputed" ;
label define INDCAT    1 "$0" 2 "$1-$4,999" 3 "$5,000-$6,999"
                       4 "$7,000-$8,999" 5 "$9,000-$11,999"
                       6 "$12,000-$14,999" 7 "$15,000-$19,999"
                       8 "$20,000-$24,999" 9 "$25,000-$29,999"
                       10 "$30,000-$39,999" 11 "$40,000-$49,999"
                       12 "$50,000-$74,999" 13 "$75,000+" ;
label define PERINC    1 "$0-$8,999" 2 "$9,000-$19,999" 3 "$20,000-$39,999"
                       4 "$40,000-$74,999" 5 "$75,000+" ;
label define PERINC2   1 "$0-9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" ;
label define PERINC3   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" 8 "12-17 Years Old" ;
label define TOTINC    0 "No family income" ;
label define IITOTINC  1 "All income sources from questionnaire"
                       3 "At least 1 of sources were stat or logic imputed" ;
label define TOTCAT    1 "$0" 2 "$1-$4,999" 3 "$5,000-$6,999"
                       4 "$7,000-$8,999" 5 "$9,000-$11,999"
                       6 "$12,000-$14,999" 7 "$15,000-$19,999"
                       8 "$20,000-$24,999" 9 "$25,000-$29,999"
                       10 "$30,000-$39,999" 11 "$40,000-$49,999"
                       12 "$50,000-$74,999" 13 "$75,000+" ;
label define FAMINC    1 "$0-$8,999" 2 "$9,000-$19,999" 3 "$20,000-$39,999"
                       4 "$40,000-$74,000" 5 "$75,000+" ;
label define FAMINC2   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" ;
label define FAMINC3   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" 8 "12-17 Years old" ;
label define WELFARE   1 "Yes, respondent or another fam member on welfare"
                       2 "No, there was no one in the family on welfare" ;
label define HALFLAG   0 "Never used (IRHALRC = 9)"
                       1 "Ever used (IRHALRC = 1-5)" ;
label define HALYR     0 "Did not use in the past year (IRHALRC = 4-5,9)"
                       1 "Used within the past year (IRHALRC = 1-3)" ;
label define HALMON    0 "Did not use in the past month (IRHALRC = 2-5,9)"
                       1 "Used within the past month (IRHALRC = 1)" ;
label define PCPFLAG   0 "Never used (IRPCPRC = 9)"
                       1 "Ever used (IRPCPRC = 1-5)" ;
label define PCPYR     0 "Did not use in the past year (IRPCPRC = 4-5,9)"
                       1 "Used within the past year (IRPCPRC = 1-3)" ;
label define PCPMON    0 "Did not use in the past month (IRPCPRC = 2-5,9)"
                       1 "Used within the past month (IRPCPRC = 1)" ;
label define STMFLAG   0 "Never used (IRSTMRC = 9)"
                       1 "Ever used (IRSTMRC = 1-5)" ;
label define STMYR     0 "Did not use in the past year (IRSTMRC = 4-5,9)"
                       1 "Used within the past year (IRSTMRC = 1-3)" ;
label define STMMON    0 "Did not use in the past month (IRSTMRC = 2-5,9)"
                       1 "Used within the past month (IRSTMRC = 1)" ;
label define SEDFLAG   0 "Never used (IRSEDRC = 9)"
                       1 "Ever used (IRSEDRC = 1-5)" ;
label define SEDYR     0 "Did not use in the past year (IRSEDRC = 4-5,9)"
                       1 "Used within the past year (IRSEDRC = 1-3)" ;
label define SEDMON    0 "Did not use in the past month (IRSEDRC = 2-5,9)"
                       1 "Used within the past month (IRSEDRC = 1)" ;
label define TRQFLAG   0 "Never used (IRTRNRC = 9)"
                       1 "Ever used (IRTRNRC = 1-5)" ;
label define TRQYR     0 "Did not use in the past year (IRTRNRC = 4-5,9)"
                       1 "Used within the past year (IRTRNRC = 1-3)" ;
label define TRQMON    0 "Did not use in the past month (IRTRNRC = 2-5,9)"
                       1 "Used within the past month (IRTRNRC = 1)" ;
label define ANLFLAG   0 "Never used (IRANLRC = 9)"
                       1 "Ever used (IRANLRC = 1-5)" ;
label define ANLYR     0 "Did not use in the past year (IRANLRC = 4-5,9)"
                       1 "Used within the past year (IRANLRC = 1-3)" ;
label define ANLMON    0 "Did not use in the past month (IRANLRC = 2-5,9)"
                       1 "Used within the past month (IRANLRC = 1)" ;
label define ALCFLAG   0 "Never used (IRALCRC = 9)"
                       1 "Ever used (IRALCRC = 1-5)" ;
label define ALCYR     0 "Did not use in the past year (IRALCRC = 4-5,9)"
                       1 "Used within the past year (IRALCRC = 1-3)" ;
label define ALCMON    0 "Did not use in the past month (IRALCRC = 2-5,9)"
                       1 "Used within the past month (IRALCRC = 1)" ;
label define CIGFLAG   0 "Never used (IRCIGRC = 9)"
                       1 "Ever used (IRCIGRC = 1-5)" ;
label define CIGYR     0 "Did not use in the past year (IRCIGRC = 4-5,9)"
                       1 "Used within the past year (IRCIGRC = 1-3)" ;
label define CIGMON    0 "Did not use in the past month (IRCIGRC = 2-5,9)"
                       1 "Used within the past month (IRCIGRC = 1)" ;
label define SMKFLAG   0 "Never used (IROTBRC = 9)"
                       1 "Ever used (IROTBRC = 1-5)" ;
label define SMKYR     0 "Did not use in the past year (IROTBRC = 4-5,9)"
                       1 "Used within the past year (IROTBRC = 1-3)" ;
label define SMKMON    0 "Did not use in the past month (IROTBRC = 2-5,9)"
                       1 "Used within the past month (IROTBRC = 1)" ;
label define HERFLAG   0 "Never used (IRHERRC = 9)"
                       1 "Ever used (IRHERRC = 1-5)" ;
label define HERYR     0 "Did not use in the past year (IRHERRC = 4-5,9)"
                       1 "Used within the past year (IRHERRC = 1-3)" ;
label define HERMON    0 "Did not use in the past month (IRHERRC = 2-5,9)"
                       1 "Used within the past month (IRHERRC = 1)" ;
label define STRFLAG   0 "Never used (IRSTRRC = 9)"
                       1 "Ever used (IRSTRRC = 1-5)" ;
label define STRYR     0 "Did not use in the past year (IRSTRRC = 4-5,9)"
                       1 "Used within the past year (IRSTRRC = 1-3)" ;
label define STRMON    0 "Did not use in the past month (IRSTRRC = 2-5,9)"
                       1 "Used within the past month (IRSTRRC = 1)" ;
label define MRJFLAG   0 "Never used (IRMJRC = 9)"
                       1 "Ever used (IRMJRC = 1-6)" ;
label define MRJYR     0 "Did not use in the past year (IRMJRC = 5-6,9)"
                       1 "Used within the past year (IRMJRC = 1-4)" ;
label define MRJMON    0 "Did not use in the past month (IRMJRC = 3-6,9)"
                       1 "Used within the past month (IRMJRC = 1-2)" ;
label define COCFLAG   0 "Never used (IRCOCRC = 9)"
                       1 "Ever used (IRCOCRC = 1-6)" ;
label define COCYR     0 "Did not use in the past year (IRCOCRC = 5-6,9)"
                       1 "Used within the past year (IRCOCRC = 1-4)" ;
label define COCMON    0 "Did not use in the past month (IRCOCRC = 3-6,9)"
                       1 "Used within the past month (IRCOCRC = 1-2)" ;
label define CRKFLAG   0 "Never used (IRCRKRC = 9)"
                       1 "Ever used (IRCRKRC = 1-6)" ;
label define CRKYR     0 "Did not use in the past year (IRCRKRC= 5-6,9)"
                       1 "Used within the past year (IRCRKRC = 1-4)" ;
label define CRKMON    0 "Did not use in the past month (IRCRKRC = 3-6,9)"
                       1 "Used within the past month (IRCRKRC = 1-2)" ;
label define INHFLAG   0 "Never used (IRINHRC = 9)"
                       1 "Ever used (IRINHRC = 1-6)" ;
label define INHYR     0 "Did not use in the past year (IRINHRC = 5-6,9)"
                       1 "Used within the past year (IRINHRC = 1-4)" ;
label define INHMON    0 "Did not use in the past month (IRINHRC = 3-6,9)"
                       1 "Used within the past month (IRINHRC = 1-2)" ;
label define ICEFLAG   0 "Never used (IRICERC = 9)"
                       1 "Ever used (IRICERC = 1-6)" ;
label define ICEYR     0 "Did not use in the past year (IRICERC = 4-6,9)"
                       1 "Used within the past year (IRICERC = 1-3)" ;
label define ICEMON    0 "Did not use in the past month (IRICERC = 2-6,9)"
                       1 "Used within the past month (IRICERC = 1)" ;
label define NEEDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE VAR BLANK" ;
label define NDL90REC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE VAR BLANK" ;
label define NEDFLAG3  0 "Never used (NDL90REC=91,98)"
                       1 "Ever used (NDL90REC=1-9)" ;
label define NEDYR3    0 "Never used (NDL90REC=4-6,9,91,98)"
                       1 "Ever used (NDL90REC=1-3,8)" ;
label define HALYRF    0 "Never used or did not use in past year (IRHALFQ=9)"
                       1 "Any use within the past year (IRHALFQ=1-8)" ;
label define HALMONF   0 "Did not use monthly/more past year (IRHALFQ=6-9)"
                       1 "Used monthly or more often past year (IRHALFQ=1-5)" ;
label define HALWKF    0 "Did not use weekly or more past year (IRHALFQ=4-9)"
                       1 "Used weekly or more often past year (IRHALFQ=1-3)" ;
label define HALOCCF   0 "Used monthly/more or none in pst yr(IRHALFQ=1-5,9)"
                       1 "Used past year but less than monthly (IRHALFQ=6-8)" ;
label define HALDLYF   0 "Did not use daily/almost daily pst yr(IRHALFQ=3-9)"
                       1 "Used daily/almost daily in past year (IRHALFQ=1-2)" ;
label define STMYRF    0 "Never used or did not use in past year (IRSTMFQ=9)"
                       1 "Any use within the past year (IRSTMFQ=1-8)" ;
label define STMMONF   0 "Did not use monthly/more past year (IRSTMFQ=6-9)"
                       1 "Used monthly or more often past year (IRSTMFQ=1-5)" ;
label define STMWKF    0 "Did not use weekly or more past year (IRSTMFQ=4-9)"
                       1 "Used weekly or more often past year (IRSTMFQ=1-3)" ;
label define STMOCCF   0 "Used monthly/more or none in pst yr(IRSTMFQ=1-5,9)"
                       1 "Used past year but less than monthly (IRSTMFQ=6-8)" ;
label define STMDLYF   0 "Did not use daily/almost daily pst yr(IRSTMFQ=3-9)"
                       1 "Used daily/almost daily in past year (IRSTMFQ=1-2)" ;
label define SEDYRF    0 "Never used or did not use in past year (IRSEDFQ=9)"
                       1 "Any use within the past year (IRSEDFQ=1-8)" ;
label define SEDMONF   0 "Did not use monthly/more past year (IRSEDFQ=6-9)"
                       1 "Used monthly or more often past year (IRSEDFQ=1-5)" ;
label define SEDWKF    0 "Did not use weekly or more past year (IRSEDFQ=4-9)"
                       1 "Used weekly or more often past year (IRSEDFQ=1-3)" ;
label define SEDOCCF   0 "Used monthly/more or none in pst yr(IRSEDFQ=1-5,9)"
                       1 "Used past year but less than monthly (IRSEDFQ=6-8)" ;
label define SEDDLYF   0 "Did not use daily/almost daily pst yr(IRSEDFQ=3-9)"
                       1 "Used daily/almost daily in past year (IRSEDFQ=1-2)" ;
label define TRQYRF    0 "Never used or did not use in past year (IRTRNFQ=9)"
                       1 "Any use within the past year (IRTRNFQ=1-8)" ;
label define TRQMONF   0 "Did not use monthly/more past year (IRTRNFQ=6-9)"
                       1 "Used monthly or more often past year (IRTRNFQ=1-5)" ;
label define TRQWKF    0 "Did not use weekly or more past year (IRTRNFQ=4-9)"
                       1 "Used weekly or more often past year (IRTRNFQ=1-3)" ;
label define TRQOCCF   0 "Used monthly/more or none in pst yr(IRTRNFQ=1-5,9)"
                       1 "Used past year but less than monthly (IRTRNFQ=6-8)" ;
label define TRQDLYF   0 "Did not use daily/almost daily pst yr(IRTRNFQ=3-9)"
                       1 "Used daily/almost daily in past year (IRTRNFQ=1-2)" ;
label define ANLYRF    0 "Never used or did not use in past year (IRANLFQ=9)"
                       1 "Any use within the past year (IRANLFQ=1-8)" ;
label define ANLMONF   0 "Did not use monthly/more past year (IRANLFQ=6-9)"
                       1 "Used monthly or more often past year (IRANLFQ=1-5)" ;
label define ANLWKF    0 "Did not use weekly or more past year (IRANLFQ=4-9)"
                       1 "Used weekly or more often past year (IRANLFQ=1-3)" ;
label define ANLOCCF   0 "Used monthly/more or none in pst yr(IRANLFQ=1-5,9)"
                       1 "Used past year but less than monthly (IRANLFQ=6-8)" ;
label define ANLDLYF   0 "Did not use daily/almost daily pst yr(IRANLFQ=3-9)"
                       1 "Used daily/almost daily in past year (IRANLFQ=1-2)" ;
label define ALCYRF    0 "Never used or not used in past year (IRALCFQ=9)"
                       1 "Any use within the past year (IRALCFQ=1-8)" ;
label define ALCMONF   0 "Did not use monthly/more past year (IRALCFQ=6-9)"
                       1 "Used monthly or more often past year (IRALCFQ=1-5)" ;
label define ALCWKF    0 "Did not use weekly or more past year (IRALCFQ=4-9)"
                       1 "Used weekly or more in past year (IRALCFQ=1-3)" ;
label define ALCOCCF   0 "Used monthly/more or none in pst yr(IRALCFQ=1-5,9)"
                       1 "Used past year but less than monthly (IRALCFQ=6-8)" ;
label define ALCDLYF   0 "Did not use daily/almost daily pst yr(IRALCFQ=3-9)"
                       1 "Used daily/almost daily in past year (IRALCFQ=1-2)" ;
label define SMKYRF    0 "Never used or did not use in past year (IROTBFQ=9)"
                       1 "Any use within the past year (IROTBFQ=1-8)" ;
label define SMKMONF   0 "Did not use monthly/more past year (IROTBFQ=6-9)"
                       1 "Used monthly or more often past year (IROTBFQ=1-5)" ;
label define SMKWKF    0 "Did not use weekly or more past year (IROTBFQ=4-9)"
                       1 "Used weekly or more often past year (IROTBFQ=1-3)" ;
label define SMKOCCF   0 "Used monthly/more or none in pst yr(IROTBFQ=1-5,9)"
                       1 "Used past year but less than monthly (IROTBFQ=6-8)" ;
label define SMKDLYF   0 "Did not use daily/almost daily pst yr(IROTBFQ=3-9)"
                       1 "Used daily/almost daily in past year (IROTBFQ=1-2)" ;
label define MRJYRF    0 "Never used or did not use in past year (IRMJFQ=10)"
                       1 "Any use within the past year (IRMJFQ=1-9)" ;
label define MRJMONF   0 "Did not use monthly/more past year (IRMJFQ=7-10)"
                       1 "Used monthly or more in past year (IRMJFQ=1-6)" ;
label define MRJWKF    0 "Did not use weekly/more past year (IRMJFQ=5-10)"
                       1 "Used weekly or more in past year (IRMJFQ=1-4)" ;
label define MRJOCCF   0 "Used monthly/more or none in pst yr(IRMJFQ=1-6,10)"
                       1 "Used past year but less than monthly (IRMJFQ=7-9)" ;
label define MRJDLYF   0 "Did not use daily/almost daily pst yr(IRMJFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRMJFQ=1-3)" ;
label define COCYRF    0 "Never used or did not use in past year (IRCOCFQ=9)"
                       1 "Any use within the past year (IRCOCFQ = 1-8)" ;
label define COCMONF   0 "Did not use monthly/more past year (IRCOCFQ=6-9)"
                       1 "Used monthly or more often past year (IRCOCFQ=1-5)" ;
label define COCWKF    0 "Did not use weekly or more past year (IRCOCFQ=4-9)"
                       1 "Used weekly or more often past year (IRCOCFQ=1-3)" ;
label define COCOCCF   0 "Used monthly/more or none in pst yr(IRCOCFQ=1-5,9)"
                       1 "Used past year but less than monthly (IRCOCFQ=6-8)" ;
label define COCDLYF   0 "Did not use daily/almost daily pst yr(IRCOCFQ=3-9)"
                       1 "Used daily/almost daily in past year (IRCOCFQ=1-2)" ;
label define INHYRF    0 "Never used or did not use in past year (IRINHFQ=9)"
                       1 "Any use within the past year (IRINHFQ=1-8)" ;
label define INHMONF   0 "Did not use monthly/more past year (IRINHFQ=6-9)"
                       1 "Used monthly or more often past year (IRINHFQ=1-5)" ;
label define INHWKF    0 "Did not use weekly or more past year (IRINHFQ=4-9)"
                       1 "Used weekly or more often past year (IRINHFQ=1-3)" ;
label define INHOCCF   0 "Used monthly/more or none in pst yr(IRINHFQ=1-5,9)"
                       1 "Used past year but less than monthly (IRINHFQ=6-8)" ;
label define INHDLYF   0 "Did not use daily/almost daily pst yr(IRINHFQ=3-9)"
                       1 "Used daily/almost daily in past year (IRINHFQ=1-2)" ;
label define PSYFLAG2  0 "Never used (ALL SOURCE VARIABLES = 9)"
                       1 "Ever used (ANY SOURCE VARIABLE < 9)" ;
label define PSYYR2    0 "Did not use within past year (ALL SOURCE VARS > 3)"
                       1 "Used in past year (ANY SOURCE VARIABLE < 4)" ;
label define PSYMON2   0 "Did not use in past month (ALL SOURCE VARS > 1)"
                       1 "Used in past month (ANY SOURCE VARIABLE = 1)" ;
label define SUMFLAG   0 "Never used (ALL SOURCE VARIABLES = 0)"
                       1 "Ever used (ANY SOURCE VARIABLE = 1)" ;
label define SUMYR     0 "Did not use in past year (ALL SOURCE VARS =0)"
                       1 "Used in past year (ANY SOURCE VARIABLE = 1)" ;
label define SUMMON    0 "Did not use in past month (ALL SOURCE VARS = 0)"
                       1 "Used in past month (ANY SOURCE VARIABLE = 1)" ;
label define MJOFLAG   0 "Never used MJ/has used both MJ & anothr illct drug"
                       1 "Marijuana is only (illicit) drug ever used" ;
label define MJOYR2    0 "MJ not used past yr/Used MJ & othr drug past yr"
                       1 "Marijuana is only (illicit) drug in past year" ;
label define MJOMON2   0 "MJ not used past mnth/Used MJ & othr drug past mo"
                       1 "Marijuana only (illicit) drug in past month" ;
label define IEMFLAG   0 "Never used drug/used only marijuana"
                       1 "Illicit drug except for marijuana are ever used" ;
label define IEMYR     0 "Never used drug/used only marijuana past year"
                       1 "Illicit drug except for marijuana used past year" ;
label define IEMMON    0 "Never used drug/used only marijuana past month"
                       1 "Illicit drug except for marijuana used past month" ;
label define HSPHCONC  1 "Greater than or equaled 50 percent"
                       2 "Greater than or equaled 10 pcnt, less than 50 pcnt"
                       3 "Less than 10 percent" ;
label define HSPPCONC  1 "Greater than or equaled 50 percent"
                       2 "Greater than or equaled 10 pcnt, less than 50 pcnt"
                       3 "Less than 10 percent" ;
label define OWNOCONC  1 "Greater than or equaled 50 percent"
                       2 "Greater than or equaled 10 pcnt, less than 50 pcnt"
                       3 "Less than 10 pcnt" ;
label define UCLASS9   0 "Above poverty level" 1 "Below poverty level" ;
label define QC06      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define QC09      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       91 "NEVER USED SMOKELESS TOBACCO" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AL02      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 91 "NEVER USED ALCOHOL"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SE04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 98 "BLANK (NO ANSWER)" ;
label define TR04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 98 "BLANK (NO ANSWER)" ;
label define ST04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 98 "BLANK (NO ANSWER)" ;
label define ST07      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       93 "NEVER USED AMPHETAMINES WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define AN04      1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 98 "BLANK (NO ANSWER)" ;
label define MJ04      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 91 "NEVER USED MARIJUANA"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define IN04      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 91 "NEVER USED INHALANTS"
                       98 "BLANK (NO ANSWER)" ;
label define CC04      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or more months ago but less than 6 months ago"
                       4 "6 or more months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 91 "NEVER USED COCAINE"
                       94 "DON'T KNOW" 98 "BLANK (NO ANSWER)" ;
label define CC11      1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago" 91 "NEVER USED COCAINE"
                       93 "NEVER USED COCAINE WITH A NEEDLE" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define CK01      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 month ago"
                       3 "1 or months ago but less than 6 months ago"
                       4 "6 or months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 years ago"
                       6 "3 or more years ago" 91 "NEVER USED CRACK"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LS05      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define LS08      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago" 91 "NEVER USED PCP"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HE04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HE07      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "NEVER USED HEROIN WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ND02      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months"
                       3 "6 or more months ago but less than a year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago"
                       91 "NEVER USED ANY DRUG FOR NONMEDICAL REASONS"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SP04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "6 or more months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago but less than 10 years ago"
                       6 "10 or more years ago" 91 "NEVER USED ICE"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SP08      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 months ago"
                       3 "More than 6 months ago but less than 1 year ago"
                       4 "1 or more years ago but less than 3 years ago"
                       5 "3 or more years ago"
                       91 "NEVER USED ANABOLIC STEROIDS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MJTOT2    1 "Never used marijuana (MJTOT = 81,91)"
                       2 "1-2 times (MJTOT = 1)" 3 "3-10 times (MJTOT = 2,3)"
                       4 "11-99 times (MJTOT = 4,5)"
                       5 "100 or more times (MJTOT = 6,7)"
                       6 "Unknown (MJTOT = 85,94,97,98)" ;
label define COCTOT2   1 "Never used cocaine (COCTOT = 81,91)"
                       2 "1-2 times (COCTOT = 1)"
                       3 "3-10 times (COCTOT = 2,3)"
                       4 "11-99 times (COCTOT = 4,5)"
                       5 "100 or more times (COCTOT = 6,7)"
                       6 "Unknown (COCTOT = 85,97,98)" ;
label define MJTOT3    1 "1-2 times (MJTOT2 = 2)" 2 "3-10 times (MJTOT2 = 3)"
                       3 "11-99 times (MJTOT2 = 4)"
                       4 "100 or more times (MJTOT2 = 5)"
                       5 "Never used marijuana (MJTOT2 = 1)" ;
label define COCTOT3   1 "1-2 times (COCTOT2 = 2)"
                       2 "3-10 times (COCTOT2 = 3)"
                       3 "11-99 times (COCTOT2 = 4)"
                       4 "100 or more times (COCTOT2 = 5)"
                       5 "Never used cocaine (COCTOT2 = 1)" ;
label define MJDY30A2  1 "None/never used marijuana (MJDAY30A = 0,81,91,93)"
                       2 "1-2 days (MJDAY30A = 1-2)"
                       3 "3-4 days (MJDAY30A = 3-4)"
                       4 "5-19 days (MJDAY30A = 5-19)"
                       5 "20-30 days (MJDAY30A = 20-30)"
                       6 "Unknown (MJDAY30A = 85,94,95,98)" ;
label define ALCDAYS2  1 "None or never used alcohol (ALCDAYS = 0,81,91,93)"
                       2 "1-2 days (ALCDAYS = 1-2)"
                       3 "3-4 days (ALCDAYS = 3-4)"
                       4 "5-19 days (ALCDAYS = 5-19)"
                       5 "20-30 days (ALCDAYS = 20-31)"
                       6 "Don't know, bad data, or blank (no answer)" ;
label define MRJMON2   1 "Did not use in past month (MRJMON = 0)"
                       2 "Used within the past month (MRJMON = 1)" ;
label define ALCMON2   1 "Did not use in the past month (ALCMON = 0)"
                       2 "Used within the past month (ALCMON = 1)" ;
label define CIGMON2   1 "Did not use in past month (CIGMON = 0)"
                       2 "Used within past month (CIGMON = 1)" ;
label define LSD2      0 "Never used hallucinogens (LSD = 2,81,91,97,98)"
                       1 "Ever used LSD (LSD = 1)" ;
label define PEYOTE2   0 "Never used hallucinogens (PEYOTE = 2,81,91,97,98)"
                       1 "Ever used Peyote (PEYOTE = 1)" ;
label define MESC2     0 "Never used hallucinogens (MESC = 2,81,91,97,98)"
                       1 "Ever used Mescaline (MESC = 1)" ;
label define PSILCY2   0 "Never used hallucinogens (PSILCY = 2,81,91,97,98)"
                       1 "Ever used Psilocybin (PSILCY = 1)" ;
label define ECSTASY2  0 "Never used hallucinogens (ECSTASY=2,81,91,97,98)"
                       1 "Ever used Ecstasy (ECSTASY=1)" ;
label define GAS2      0 "Never inhaled (GAS = 2,81,91,98)"
                       1 "Ever inhaled (GAS = 1,3)" ;
label define LGAS2     0 "Never inhaled (LGAS=2,81,91,98)"
                       1 "Ever inhaled (LGAS=1,3)" ;
label define SPPAINT2  0 "Never inhaled (SPPAINT = 2,81,91,98)"
                       1 "Ever inhaled (SPPAINT = 1,3)" ;
label define AEROS2    0 "Never inhaled (AEROS = 2,81,91,98)"
                       1 "Ever inhaled (AEROS = 1,3)" ;
label define GLUE2     0 "Never inhaled (GLUE = 2,81,91,98)"
                       1 "Ever inhaled (GLUE = 1,3)" ;
label define SOLVENT2  0 "Never inhaled (SOLVENT = 2,81,91,98)"
                       1 "Ever inhaled (SOLVENT = 1,3)" ;
label define AMYLNIT2  0 "Never inhaled (AMYLNIT = 2,81,91,98)"
                       1 "Ever inhaled (AMYLNIT = 1,3)" ;
label define ETHER2    0 "Never inhaled (ETHER = 2,81,91,98)"
                       1 "Ever inhaled (ETHER = 1,3)" ;
label define NITOXID2  0 "Never inhaled (NITOXID = 2,81,91,98)"
                       1 "Ever inhaled (NITOXID = 1,3)" ;
label define CLEFLU2   0 "Never inhaled (CLEFLU = 2,81,91,98)"
                       1 "Ever inhaled (CLEFLU = 1,3)" ;
label define COCSNIF2  0 "Never/no use pst 12 mos(COCSNIFF=2,81,83,91,93,97)"
                       1 "Sniffed/snorted in past 12 months (COCSNIFF = 1)" ;
label define FREEBAS2  0 "Never/no use pst 12 mos(FREEBASE=2,81,83,91,93,97)"
                       1 "Freebased in past 12 months (FREEBASE = 1,3)" ;
label define COCSWAL2  0 "Never/no use pst 12 mos(COCSWAL=2,81,83,91,93,97)"
                       1 "Swallowed/drank in past 12 months (COCSWAL = 1)" ;
label define COCIV2    0 "Never/no use past 12 mos (COCIV=2,81,83,91,93,97)"
                       1 "Injected in the past 12 months (COCIV = 1,3)" ;
label define MJDY30A3  1 "1-2 days (MJDAY30A2 = 2)"
                       2 "3-4 days (MJDAY30A2 = 3)"
                       3 "5-19 days (MJDAY30A2 = 4)"
                       4 "20-30 days (MJDAY30A2 = 5)"
                       5 "None or never used marijuana (MJDAY30A2 = 1)" ;
label define ALCDAYS3  1 "None or never used alcohol (ALCDAYS2 = 1)"
                       2 "1-4 days (ALCDAYS2 = 2-3)"
                       3 "5-19 days (ALCDAYS2 = 4)"
                       4 "20-30 days (ALCDAYS2 = 5)" ;
label define DRINKER2  0 "Never/no ALC use (ALCMON=0 and DR5DAY=0,81,91,93)"
                       1 "Alcohol use (ALCMON = 1 and DR5DAY = 0-30)" ;
label define HVYDRK2   0 "Never/no heavy use (DR5DAY=0-4,81,91,93)"
                       1 "Heavy alcohol use (DR5DAY = 5-30)" ;
label define AVCIG2    1 "None/never smoked cigarettes (AVCIG=81,89,91,99)"
                       2 "Currently smoke < a pack per day (AVCIG = 1-3)"
                       3 "Currently smoke a pack or more per day (AVCIG=4-6)" ;
label define RACESEX   1 "White male (SEX = 1 and RACE = 1)"
                       2 "Black male (SEX = 1 and RACE = 2)"
                       3 "Hispanic male (SEX = 1 and RACE = 3)"
                       4 "White female (SEX = 2 and RACE = 1)"
                       5 "Black female (SEX = 2 and RACE = 2)"
                       6 "Hispanic female (SEX = 2 and RACE = 3)" ;
label define NOTMARJ   0 "No (ALL SOURCE VARIABLES = 0)"
                       1 "Yes (ANY SOURCE VARIABLES = 1)" ;
label define COCWAY2   0 "Never/no use past 12 months (COCWAY=2,81,83,91,93)"
                       1 "Used other ways past 12 months (COCWAY=1,3,6-9)" ;
label define RACESEX2  1 "White male (SEX=1 and RACE=1)"
                       2 "Black male (SEX=1 and RACE=2)"
                       3 "Hispanic male (SEX=1 and RACE=3)"
                       4 "Other male (SEX=1 and RACE=4)"
                       5 "White female (SEX=2 and RACE=1)"
                       6 "Black female (SEX=2 and RACE=2)"
                       7 "Hispanic female (SEX=2 and RACE=3)"
                       8 "Other female (SEX=2 and RACE=4)" ;
label define IRCDCIG   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRCDALC   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRCDMJ    1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRCDCOC   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IREFCIG   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IREFALC   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IREFMJ    1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IREFCOC   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for same effect"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRUDCIG   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRUDALC   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRUDMJ    1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRUDCOC   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRDPCIG   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used pst yr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRDPALC   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRDPMJ    1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used pst yr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRDPCOC   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug used pst yr"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRWSCIG   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRWSALC   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRWSMJ    1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRWSCOC   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define AVCIG3    0 "None/never/< pack a day (AVCIG=1-3,81,89,91,98,99)"
                       1 "Currently smoke a pack or more per day (AVCIG=4-6)" ;
label define ALCPROBS  0 "No" 1 "Yes" ;
label define MJPROBS   0 "No" 1 "Yes" ;
label define COCPROBS  0 "No" 1 "Yes" ;
label define CIGPROBS  0 "No" 1 "Yes" ;
label define IRALCAGG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCARG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCABS  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCHIG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCJOB  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCMAT  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCREL  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCFRD  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCTOS  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCHOL  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCDRU  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCINT  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCREM  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCQUI  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCMOR  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCSHO  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCALO  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCBRK  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRNOBOOZ  1 "No use of alcohol in the past year"
                       2 "Used alcohol in the past year" ;
label define ANYALC    0 "No" 1 "Yes" ;
label define THREALC   0 "No" 1 "Yes" ;
label define DRUNKYR2  0 "Unknown (DRUNKYR = 85,96,97,98)"
                       1 "Drunk more than twice a month (DRUNKYR = 1-4)"
                       2 "Drunk twice a month or less (DRUNKYR = 5-8)"
                       3 "Never drunk in past year (DRUNKYR = 9)" ;
label define IRDEP     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRARG     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRALN     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRANX     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRHLT     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRNTK     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRUPS     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRLSW     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRSSP     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRCPE     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IREMG     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRDEP1    116 "Methaqualone, Parest, Quaalude, Sopor"
                       201 "Valium" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED" 241 "Prozac"
                       312 "Ionamin" 313 "Fastin, Phentermine"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 375 "sic"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       501 "Lighter fluids, Gasoline" 502 "Spray paints"
                       510 "OTHER Inhalant, NOT SPECIFIED" 557 "Hagwash"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones I've tried"
                       809 "Pills" 810 "Hemp" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       869 "sic" 874 "Premarin" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP2    120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack, rock"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       840 "Cough medicine (contents not specified) <OTC>"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP3    339 "Amphetamines (speed generically)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack, rock"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP4    415 "Codeine" 601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       805 "Cocaine, Coke" 807 "Alcohol" 809 "Pills"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP5    607 "OTHER Hallucinogen, NOT SPECIFIED"
                       999 "LEGITIMATE SKIP" ;
label define IRARG1    209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 415 "Codeine" 440 "Soma"
                       557 "Hagwash" 601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       808 "All of the ones I've tried" 810 "Hemp"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       818 "Nicotine" 824 "Steroids" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRARG2    221 "OTHER Tranquilizer, NOT SPECIFIED" 324 "Uppers"
                       332 "Ephedrine (HCl)"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       408 "Dilaudid" 601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       840 "Cough medicine (contents not specified) <OTC>"
                       999 "LEGITIMATE SKIP" ;
label define IRARG3    601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRARG4    508 "Nitrous oxide, whippets, dentist gas"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRARG5    999 "LEGITIMATE SKIP" ;
label define IRALN1    201 "Valium" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED" 241 "Prozac"
                       312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 355 "Crystal meth" 401 "Darvon"
                       406 "Oxycodone, Percodan, Roxicet" 408 "Dilaudid"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 707 "Black Tar"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       808 "All of the ones I've tried" 809 "Pills"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRALN2    209 "Xanax"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin."
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       840 "Cough medicine (contents not specified)"
                       848 "Liquid vitamin <OTC>" 999 "LEGITIMATE SKIP" ;
label define IRALN3    803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRALN4    510 "OTHER Inhalant, NOT SPECIFIED" 807 "Alcohol"
                       809 "Pills" 999 "LEGITIMATE SKIP" ;
label define IRALN5    607 "OTHER Hallucinogen, NOT SPECIFIED"
                       999 "LEGITIMATE SKIP" ;
label define IRANX1    209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 247 "Adapin, Doxepin, Sinequan"
                       271 "Zoloft" 301 "Dexedrine" 309 "Didrex"
                       312 "Ionamin" 313 "Fastin, Phentermine"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine" 336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       354 "Vivarin <OTC>" 355 "Crystal meth" 375 "sic"
                       408 "Dilaudid" 415 "Codeine"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       435 "Tylenol, Tylenol Extra-Strength <OTC>"
                       510 "OTHER Inhalant, NOT SPECIFIED" 557 "Hagwash"
                       601 "LSD (acid, white lightning)"
                       605 "Phencyclidine (angel dust, PCP)"
                       606 "Ecstasy (MDMA), X-TC"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       808 "All of the ones I've tried" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       818 "Nicotine"
                       873 "Contraceptives, Feutal, Ortho Novum"
                       998 "BLANK (NOT ANSWERED)" 999 "LEGITIMATE SKIP" ;
label define IRANX2    120 "Downers"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 601 "LSD (acid, white lightning)"
                       604 "Psilcybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       840 "Cough medicine (contents not specified) <OTC>"
                       999 "LEGITIMATE SKIP" ;
label define IRANX3    326 "White cross" 702 "Heroin" 803 "Marijuana"
                       805 "Cocaine, Coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRANX4    510 "OTHER Inhalant, NOT SPECIFIED" 803 "Marijuana"
                       807 "Alcohol" 809 "Pills" 999 "LEGITIMATE SKIP" ;
label define IRANX5    607 "OTHER Hallucinogen, NOT SPECIFIED"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT1    209 "Xanax" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 362 "Benadryl" 408 "Dilaudid"
                       501 "Gasoline or lighter fluids" 557 "Hagwash"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       639 "Cloves, Nutmet" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       809 "Pills" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       818 "Nicotine" 870 "sic" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT2    332 "see also 346"
                       339 "Amphetamines (speed generically)"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       506 "Amyl nitrate, poppers, locker rm odorizer,rush"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       865 "Diuretics, Water pills" 999 "LEGITIMATE SKIP" ;
label define IRHLT3    339 "Amphetamines (speed generically)" 348 "Crystal"
                       702 "Heroin" 803 "Marijuana" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT4    807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRHLT5    999 "LEGITIMATE SKIP" ;
label define IRNTK1    116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 247 "Adapin, Doxepin, Sinequan"
                       271 "Zoloft" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       354 "Vivarin <OTC>" 355 "Crystal meth" 401 "Darvon"
                       407 "Demerol" 408 "Dilaudid"
                       409 "Tylenol with Codeine, Tylenol" 418 "Methadone"
                       501 "Gasoline or lighter fluids" 502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,SuperGlue,rubber cem.."
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 609 "sic"
                       702 "Heroin" 704 "Dope"
                       705 "Speel Ball (heroin + cocaine)"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 810 "Hemp" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 815 "Coffee"
                       823 "sic"
                       840 "Cough medicine (contents not specified) <OTC>"
                       873 "Contraceptives, Feutal, Ortho Novum"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRNTK2    322 "Methamphetamine (speed or ice or crank)"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       407 "Demerol" 420 "OTHER Analgesic, NOT SPECIFIED"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       506 "Amyl nitrate, poppers, locker rm odorizer,rush"
                       508 "Nitrous oxide, whippets, dentist gas"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 809 "Pills"
                       813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK3    324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)"
                       601 "LSD (acid, white lightning)" 602 "Peyote"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK4    415 "Codeine" 510 "OTHER Inhalant, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK5    201 "Valium" 607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "sic" 999 "LEGITIMATE SKIP" ;
label define IRUPS1    209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 355 "Crystal meth"
                       406 "Oxycodone, Percodan, Roxicet"
                       409 "Tylenol with Codeine, Tylenol"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin."
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones I've tried"
                       810 "Hemp" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       818 "Nicotine" 824 "Steroids"
                       840 "Cough medicine (contents not specified) <OTC>"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRUPS2    324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed generically)" 408 "Dilaudid"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin."
                       508 "Notrous oxide, whippets, dentist gas"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 809 "Pills" 811 "Muscle relaxers"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       815 "Coffee" 999 "LEGITIMATE SKIP" ;
label define IRUPS3    437 "Parafon Forte" 601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       809 "Pills" 813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS4    510 "OTHER Inhalant, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       813 "cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS5    607 "OTHER Hallucinogen, NOT SPECIFIED"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW1    201 "Valium" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers" 336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 406 "Oxycodone, Percodan, Roxicet"
                       501 "Gasoline or lighter fluids"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 810 "Hemp" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 815 "Coffee"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRLSW2    408 "Dilaudid"
                       508 "Nitrous oxide, whippets, dentist gas"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       809 "Pills" 813 "Cigarettes, tobacco not specified"
                       840 "Cough medicine (contents not specified) <OTC>"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW3    339 "Amphetamines (speed generically)"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       804 "Hashish" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW4    510 "OTHER Inhalant, NOT SPECIFIED"
                       805 "Cocaine, Coke" 999 "LEGITIMATE SKIP" ;
label define IRLSW5    607 "OTHER Hallucinogen, NOT SPECIFIED"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP1    312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       707 "Black Tar" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacco"
                       840 "Cough medicine (contents not specified) <OTC>"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRSSP2    322 "Methamphetamine (speed or ice or crank)"
                       408 "Dilaudid" 601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 809 "Pills"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP3    339 "Amphetamines (speed generically)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       809 "Pills" 813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP4    510 "OTHER Inhalant, NOT SPECIFIED"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP5    607 "OTHER Hallucinogen, NOT SPECIFIED"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE1    209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 809 "Pills" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       824 "Steroids" 877 "Methozolamide"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRCPE2    239 "Elavil" 408 "Dilaudid"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       809 "Pills" 813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE3    339 "Amphetamines (speed generically)" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE4    510 "OTHER Inhalant, NOT SPECIFIED"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE5    607 "OTHER HAllucinogen, NOT SPECIFIED"
                       999 "LEGITIMATE SKIP" ;
label define IREMG1    108 "Carbrital, Nembutal" 209 "Xanax" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or crank)"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       430 "Aspirin, Ecotrin, Empiron <OTC>" 435 "Tylenol"
                       503 "Other aerosol sprays" 601 "see also 618"
                       605 "PCP (angel dust, phencyclidine)" 606 "sic"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 815 "Coffee"
                       858 "Antibiotic" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IREMG2    339 "Amphetamines (speed generically)"
                       420 "OTHER Analgesic, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       809 "Pills" 813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IREMG3    813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IREMG4    999 "LEGITIMATE SKIP" ;
label define IREMG5    999 "LEGITIMATE SKIP" ;
label define IRAS13    1 "Never used any of the substances listed"
                       2 "Used one or more of the listed substances" ;
label define DEPCIG2   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define DEPALC2   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define DEPMRJ2   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define DEPCOC2   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define ARGCIG2   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define ARGALC2   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define ARGMRJ2   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define ARGCOC2   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define ALNCIG2   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define ALNALC2   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define ALNMRJ2   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define ALNCOC2   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define ANXCIG2   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define ANXALC2   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define ANXMRJ2   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define ANXCOC2   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define HLTCIG2   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define HLTALC2   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define HLTMRJ2   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define HLTCOC2   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define NTKCIG2   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define NTKALC2   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define NTKMRJ2   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define NTKCOC2   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define UPSCIG2   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define UPSALC2   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define UPSMRJ2   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define UPSCOC2   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define LSWCIG2   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define LSWALC2   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define LSWMRJ2   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define LSWCOC2   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define SSPCIG2   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define SSPALC2   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define SSPMRJ2   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define SSPCOC2   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define CPECIG2   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define CPEALC2   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define CPEMRJ2   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define CPECOC2   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define EMCIG2    0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define EMALC2    0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define EMMRJ2    0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define EMCOC2    0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define PRB1CIG   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define PRB1ALC   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define PRB1MRJ   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define PRB1COC   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define PRB2CIG   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define PRB2ALC   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define PRB2MRJ   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define PRB2COC   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define PRB3CIG   0 "No" 1 "Yes"
                       93 "Did not use cigarettes in the past year" ;
label define PRB3ALC   0 "No" 1 "Yes"
                       93 "Did not use alcohol in the past year" ;
label define PRB3MRJ   0 "No" 1 "Yes"
                       93 "Did not use marijuana in the past year" ;
label define PRB3COC   0 "No" 1 "Yes"
                       93 "Did not use cocaine in the past year" ;
label define ANYPROB   0 "No" 1 "Yes" ;
label define TWOPROB   0 "No" 1 "Yes" ;
label define THREPROB  0 "No" 1 "Yes" ;
label define ALCONLYL  0 "No" 1 "Yes (ALCFLAG=1 AND SUMFLAG=0)" ;
label define ALCONLYY  0 "No" 1 "Yes (ALCYR=1 AND SUMYR=0)" ;
label define ALCONLYM  0 "No" 1 "Yes (ALCMON=1 AND SUMMON=0)" ;
label define ILLONLYL  0 "No" 1 "Yes (SUMFLAG=1 AND ALCFLAG=0)" ;
label define ILLONLYY  0 "No" 1 "Yes (SUMYR=1 AND ALCYR=0)" ;
label define ILLONLYM  0 "No" 1 "Yes (SUMMON=1 AND ALCMON=0)" ;
label define MRJONLYL  0 "No" 1 "Yes (MJOFLAG=1 AND ALCFLAG=0)" ;
label define MRJONLYY  0 "No" 1 "Yes (MJOYR2=1 AND ALCYR=0)" ;
label define MRJONLYM  0 "No" 1 "Yes (MJOMON2=1 AND ALCMON=0)" ;
label define PSYONLYL  0 "No"
                       1 "Yes (PSYFLAG2=1 AND ALL OTHER SOURCE VARS=0)" ;
label define PSYONLYY  0 "No" 1 "Yes (PSYYR2=1 AND ALL OTHER SOURCE VARS=0)" ;
label define PSYONLYM  0 "No" 1 "Yes (PSYMON2=1 AND ALL OTHER SOURCE VARS=0)" ;
label define OTHONLYL  0 "No"
                       1 "Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR SOURCE VAR=1)" ;
label define OTHONLYY  0 "No"
                       1 "Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR SOURCE VAR=1)" ;
label define OTHONLYM  0 "No"
                       1 "Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR SOURCE VAR=1)" ;
label define ALCILLL   0 "No" 1 "Yes (ALCFLAG=1 AND SUMFLAG=1)" ;
label define ALCILLY   0 "No" 1 "Yes (ALCYR=1 AND SUMYR=1)" ;
label define ALCILLM   0 "No" 1 "Yes (ALCMON=1 AND SUMMON=1)" ;
label define ALCMRJL   0 "No"
                       1 "Yes (ALCFLAG,MRJFLAG=1 AND ALL OTHER SOURCE VAR=0)" ;
label define ALCMRJY   0 "No"
                       1 "Yes (ALCYR AND MRJYR=1 AND ALL OTHER SOURCE VAR=0)" ;
label define ALCMRJM   0 "No"
                       1 "Yes (ALCMON & MRJMON=1 AND ALL OTHER SOURCE VAR=0)" ;
label define ALCPSYL   0 "No"
                       1 "Yes (ALCFLAG,PSYFLAG2=1 & ALL OTHER SOURCE VAR=0)" ;
label define ALCPSYY   0 "No"
                       1 "Yes (ALCYR & PSYYR2=1 AND ALL OTHER SOURCE VAR=0)" ;
label define ALCPSYM   0 "No"
                       1 "Yes (ALCMON & PSYMON2=1 & ALL OTHER SOURCE VAR=0)" ;
label define ALCOTHL   0 "No"
                       1 "Yes (ALCFLAG=1 & NEXT 2 VAR=0 & ANY OTHER VAR=1)" ;
label define ALCOTHY   0 "No"
                       1 "Yes (ALCYR=1 & NEXT 2 VAR=0 & ANY OTHER VAR=1)" ;
label define ALCOTHM   0 "No"
                       1 "Yes (ALCMON=1 & NEXT 2 VAR=0 & ANY OTHER VAR=1)" ;
label define SUB1LIF   0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB2LIF   0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB3LIF   0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;
label define SUB1YR    0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB2YR    0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB3YR    0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;
label define SUB1MON   0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB2MON   0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB3MON   0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;
label define CHANCMJ2  0 "Did not have a chance to use marijuana"
                       1 "Had a chance to use marijuana" 94 "UNKNOWN" ;
label define CHANCOC2  0 "Did not have a chance to use cocaine"
                       1 "Had a chance to use cocaine" 94 "UNKNOWN" ;
label define CHANHAL2  0 "Did not have a chance to use hallucinogens"
                       1 "Had a chance to use hallucinogens" 94 "UNKNOWN" ;
label define CHANHER2  0 "Did not have a chance to use heroin"
                       1 "Had a chance to use heroin" 94 "UNKNOWN" ;
label define TRMTHLP2  0 "No (TRMTHELP=2)" 1 "Yes (TRMTHELP=1)" ;
label define DRNKHLP2  0 "No (DRNKHELP=2)" 1 "Yes (DRNKHELP=1)" ;
label define DRALHELP  0 "No (see note above)"
                       1 "Yes (TRMTHLP2=1 or DRNKHLP2=1)" ;
label define RURORURB  1 "Rural" 2 "Urban" ;
label define PBLACKHH  1 "Greater than or equal to 50 percent"
                       2 "Greater than or equal to 10 percent,"
                       3 "Less than 10 percent" ;
label define PBLACKP   1 "Greater than or equal to 50 percent"
                       2 "Greater than or equal to 10 percent,"
                       3 "Less than 10 percent" ;
label define PPOVERTY  1 "0 - 2.65 percent" 2 "2.66 - 5.12 percent"
                       3 "5.13 - 9.02 percent" 4 "9.03 - 16.15 percent"
                       5 "16.16 percent or more" ;
label define POWNED    1 "0 - 50.25 percent" 2 "50.26 - 67.58 percent"
                       3 "67.59 - 76.38 percent" 4 "76.39 - 83.96 percent"
                       5 "83.97 percent or more" ;
label define PRENTED   1 "0 - 16.04 percent" 2 "16.05 - 23.62 percent"
                       3 "23.63 - 32.42 percent" 4 "32.43 - 49.75 percent"
                       5 "49.75 percent or more" ;
label define OWNEDAVE  1 "0 - $44,777" 2 "$44,778 - $60,832"
                       3 "$60,833 - $85,121" 4 "$85,122 - $142,831"
                       5 "$142,832 or more" ;
label define RENTAVE   1 "0 - $315.81" 2 "$315.82 - $393.95"
                       3 "$393.96 - $476.96" 4 "$476.97 - $619.72"
                       5 "$619.72 or more" ;
label define IRKIDS    0 "None" 1 "One" 2 "Two" 3 "Three" 4 "Four" 5 "Five"
                       6 "Six or more" ;
label define CWEOCC2   990 "INDUSTRY NOT REPORTED" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define ROCCUP2   990 "OCCUPATION NOT REPORTED" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define CWEBUS2   990 "INDUSTRY NOT REPORTED" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define BUSINES2  990 "INDUSTRY NOT REPORTED" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CIGTRY = . if (CIGTRY >= 981 )
replace CIG5PK = . if (CIG5PK >= 81 )
replace CIGAGE = . if (CIGAGE >= 981 )
replace CIGYRS = . if (CIGYRS >= 981 )
replace PACKS = . if (PACKS >= 81 )
replace CIGREC = . if (CIGREC >= 81 )
replace AVCIG = . if (AVCIG >= 81 )
replace CIGTIME = . if (CIGTIME >= 9981 )
replace SNUFREC = . if (SNUFREC >= 81 )
replace OTHTOB = . if (OTHTOB >= 81 )
replace ALCTRY = . if (ALCTRY >= 981 )
replace ALCREC = . if (ALCREC >= 81 )
replace ALCAGE = . if (ALCAGE >= 981 )
replace ALCDAYS = . if (ALCDAYS >= 81 )
replace NODR30A = . if (NODR30A >= 81 )
replace DR5DAY = . if (DR5DAY >= 81 )
replace MODR30A = . if (MODR30A >= 81 )
replace MODR30DY = . if (MODR30DY >= 81 )
replace ALCPAT = . if (ALCPAT >= 81 )
replace DRUNKYR = . if (DRUNKYR >= 81 )
replace ALCBEER = . if (ALCBEER >= 81 )
replace ALCWINE = . if (ALCWINE >= 81 )
replace ALCLIQR = . if (ALCLIQR >= 81 )
replace ALCVARY = . if (ALCVARY >= 81 )
replace NOSEDAT = . if (NOSEDAT >= 81 )
replace BUTISOL = . if (BUTISOL >= 81 )
replace BUTICAPS = . if (BUTICAPS >= 81 )
replace AMYTAL = . if (AMYTAL >= 81 )
replace MEBARAL = . if (MEBARAL >= 81 )
replace PLACIDYL = . if (PLACIDYL >= 81 )
replace DORIDEN = . if (DORIDEN >= 81 )
replace NOLUDAR = . if (NOLUDAR >= 81 )
replace NEMBUTAL = . if (NEMBUTAL >= 81 )
replace SECONAL = . if (SECONAL >= 81 )
replace TUINAL = . if (TUINAL >= 81 )
replace DALMANE = . if (DALMANE >= 81 )
replace RESTORIL = . if (RESTORIL >= 81 )
replace HALCION = . if (HALCION >= 81 )
replace AMOBARB = . if (AMOBARB >= 81 )
replace PHENOBAR = . if (PHENOBAR >= 81 )
replace METHAQ = . if (METHAQ >= 81 )
replace CHHYD = . if (CHHYD >= 81 )
replace PENTOB = . if (PENTOB >= 81 )
replace SECOB = . if (SECOB >= 81 )
replace SEDNEWA = . if (SEDNEWA >= 981 )
replace SEDNEWB = . if (SEDNEWB >= 981 )
replace SEDNEWC = . if (SEDNEWC >= 981 )
replace SEDNEWD = . if (SEDNEWD >= 981 )
replace SEDNEWE = . if (SEDNEWE >= 981 )
replace SEDNOSP = . if (SEDNOSP >= 81 )
replace SEDDKNAM = . if (SEDDKNAM >= 81 )
replace SEDAGE = . if (SEDAGE >= 981 )
replace SEDTOT = . if (SEDTOT >= 81 )
replace SEDREC = . if (SEDREC >= 81 )
replace SEDYRFRQ = . if (SEDYRFRQ >= 81 )
replace TRNREAD = . if (TRNREAD >= 81 )
replace NOTRANQ = . if (NOTRANQ >= 81 )
replace VALIUM = . if (VALIUM >= 81 )
replace LIBRIUM = . if (LIBRIUM >= 81 )
replace LIMBTROL = . if (LIMBTROL >= 81 )
replace MENRIUM = . if (MENRIUM >= 81 )
replace SERAX = . if (SERAX >= 81 )
replace TRANXENE = . if (TRANXENE >= 81 )
replace ATIVAN = . if (ATIVAN >= 81 )
replace CENTRAX = . if (CENTRAX >= 81 )
replace XANAX = . if (XANAX >= 81 )
replace PAXIPAM = . if (PAXIPAM >= 81 )
replace BUSPAR = . if (BUSPAR >= 81 )
replace MILTOWN = . if (MILTOWN >= 81 )
replace EQUANIL = . if (EQUANIL >= 81 )
replace DEPROL = . if (DEPROL >= 81 )
replace VISTAR = . if (VISTAR >= 81 )
replace ATARAX = . if (ATARAX >= 81 )
replace DURRAX = . if (DURRAX >= 81 )
replace DIAZEPAM = . if (DIAZEPAM >= 81 )
replace SKLY = . if (SKLY >= 81 )
replace MEPROB = . if (MEPROB >= 81 )
replace TRNEWA = . if (TRNEWA >= 981 )
replace TRNEWB = . if (TRNEWB >= 981 )
replace TRNEWC = . if (TRNEWC >= 981 )
replace TRNEWD = . if (TRNEWD >= 981 )
replace TRNEWE = . if (TRNEWE >= 981 )
replace TRNOSP = . if (TRNOSP >= 81 )
replace TRDKNAM = . if (TRDKNAM >= 81 )
replace TRANAGE = . if (TRANAGE >= 981 )
replace TRANTOT = . if (TRANTOT >= 81 )
replace TRANREC = . if (TRANREC >= 81 )
replace TRNYRFRQ = . if (TRNYRFRQ >= 81 )
replace STMREAD = . if (STMREAD >= 81 )
replace NOSTIMS = . if (NOSTIMS >= 81 )
replace DEXED = . if (DEXED >= 81 )
replace DEXAMYL = . if (DEXAMYL >= 81 )
replace ESKAT = . if (ESKAT >= 81 )
replace BENZ = . if (BENZ >= 81 )
replace BIPHET = . if (BIPHET >= 81 )
replace DESOXYN = . if (DESOXYN >= 81 )
replace TENUATE = . if (TENUATE >= 81 )
replace TEPANIL = . if (TEPANIL >= 81 )
replace DIDREX = . if (DIDREX >= 81 )
replace PLEGINE = . if (PLEGINE >= 81 )
replace PRELUDIN = . if (PRELUDIN >= 81 )
replace IONAMIN = . if (IONAMIN >= 81 )
replace FASTIN = . if (FASTIN >= 81 )
replace PONDIMIN = . if (PONDIMIN >= 81 )
replace VORANIL = . if (VORANIL >= 81 )
replace SANOREX = . if (SANOREX >= 81 )
replace MAZANOR = . if (MAZANOR >= 81 )
replace RITALIN = . if (RITALIN >= 81 )
replace CYLERT = . if (CYLERT >= 81 )
replace DETAMP = . if (DETAMP >= 81 )
replace METHI = . if (METHI >= 81 )
replace METHAMP = . if (METHAMP >= 81 )
replace OBLA = . if (OBLA >= 81 )
replace STIMNEWA = . if (STIMNEWA >= 981 )
replace STIMNEWB = . if (STIMNEWB >= 981 )
replace STIMNEWC = . if (STIMNEWC >= 981 )
replace STIMNEWD = . if (STIMNEWD >= 981 )
replace STIMNEWE = . if (STIMNEWE >= 981 )
replace STIMNOSP = . if (STIMNOSP >= 81 )
replace STMDKNAM = . if (STMDKNAM >= 81 )
replace STIMAGE = . if (STIMAGE >= 981 )
replace STIMTOT = . if (STIMTOT >= 81 )
replace STIMREC = . if (STIMREC >= 81 )
replace STMYRFRQ = . if (STMYRFRQ >= 81 )
replace STNEEDLE = . if (STNEEDLE >= 81 )
replace STNDLREC = . if (STNDLREC >= 81 )
replace ANLREAD = . if (ANLREAD >= 81 )
replace ANALNONE = . if (ANALNONE >= 81 )
replace DARVON = . if (DARVON >= 81 )
replace DOLENE = . if (DOLENE >= 81 )
replace SK65A = . if (SK65A >= 81 )
replace WYGESIC = . if (WYGESIC >= 81 )
replace LEVODRO = . if (LEVODRO >= 81 )
replace PERCODAN = . if (PERCODAN >= 81 )
replace DEMEROL = . if (DEMEROL >= 81 )
replace DILAUD = . if (DILAUD >= 81 )
replace TYLCOD = . if (TYLCOD >= 81 )
replace PHENCOD = . if (PHENCOD >= 81 )
replace TALWIN = . if (TALWIN >= 81 )
replace TALWINNX = . if (TALWINNX >= 81 )
replace TALACEN = . if (TALACEN >= 81 )
replace PROPOXY = . if (PROPOXY >= 81 )
replace CODEINE = . if (CODEINE >= 81 )
replace ANILERID = . if (ANILERID >= 81 )
replace MORPHINE = . if (MORPHINE >= 81 )
replace METHDON = . if (METHDON >= 81 )
replace STADOL = . if (STADOL >= 81 )
replace ANALNEWA = . if (ANALNEWA >= 981 )
replace ANALNEWB = . if (ANALNEWB >= 981 )
replace ANALNEWC = . if (ANALNEWC >= 981 )
replace ANALNEWD = . if (ANALNEWD >= 981 )
replace ANALNEWE = . if (ANALNEWE >= 981 )
replace ANLNOSP = . if (ANLNOSP >= 81 )
replace ANLDKNAM = . if (ANLDKNAM >= 81 )
replace ANALAGE = . if (ANALAGE >= 981 )
replace ANALTOT = . if (ANALTOT >= 81 )
replace ANALREC = . if (ANALREC >= 81 )
replace ANLYRFRQ = . if (ANLYRFRQ >= 81 )
replace MJOPP = . if (MJOPP >= 981 )
replace MJAGE = . if (MJAGE >= 981 )
replace MJTOT = . if (MJTOT >= 81 )
replace MJREC = . if (MJREC >= 81 )
replace MJDAY30A = . if (MJDAY30A >= 81 )
replace MJAV30A = . if (MJAV30A >= 81 )
replace MJAV30B = . if (MJAV30B >= 81 )
replace MJAMT30A = . if (MJAMT30A >= 81 )
replace MJFRIEND = . if (MJFRIEND >= 81 )
replace MJDEALER = . if (MJDEALER >= 81 )
replace MJOTHSHR = . if (MJOTHSHR >= 81 )
replace MJGIVEN = . if (MJGIVEN >= 81 )
replace MJTRGOOD = . if (MJTRGOOD >= 81 )
replace MJTRSERV = . if (MJTRSERV >= 81 )
replace MJTRICK = . if (MJTRICK >= 81 )
replace MJOBTNON = . if (MJOBTNON >= 81 )
replace MJBUCK = . if (MJBUCK >= 9981.0 )
replace MJYRFREQ = . if (MJYRFREQ >= 81 )
replace MJJOINT = . if (MJJOINT >= 81 )
replace MJPIPE = . if (MJPIPE >= 81 )
replace MJBAKE = . if (MJBAKE >= 81 )
replace MJCHEW = . if (MJCHEW >= 81 )
replace MJWAY = . if (MJWAY >= 81 )
replace MJLFDALY = . if (MJLFDALY >= 81 )
replace INHREAD = . if (INHREAD >= 81 )
replace GAS = . if (GAS >= 81 )
replace LGAS = . if (LGAS >= 81 )
replace SPPAINT = . if (SPPAINT >= 81 )
replace AEROS = . if (AEROS >= 81 )
replace GLUE = . if (GLUE >= 81 )
replace SOLVENT = . if (SOLVENT >= 81 )
replace AMYLNIT = . if (AMYLNIT >= 81 )
replace ETHER = . if (ETHER >= 81 )
replace NITOXID = . if (NITOXID >= 81 )
replace CLEFLU = . if (CLEFLU >= 81 )
replace INHNEWA = . if (INHNEWA >= 981 )
replace INHNEWB = . if (INHNEWB >= 981 )
replace INHNEWC = . if (INHNEWC >= 981 )
replace INHNEWD = . if (INHNEWD >= 981 )
replace INHNEWE = . if (INHNEWE >= 981 )
replace INHNOSP = . if (INHNOSP >= 81 )
replace INHDKNAM = . if (INHDKNAM >= 81 )
replace INHAGE = . if (INHAGE >= 981 )
replace INHTOT = . if (INHTOT >= 81 )
replace INHREC = . if (INHREC >= 81 )
replace GAS30A = . if (GAS30A >= 81 )
replace LGAS30A = . if (LGAS30A >= 81 )
replace SPPAN30A = . if (SPPAN30A >= 81 )
replace AEROS30A = . if (AEROS30A >= 81 )
replace GLUE30A = . if (GLUE30A >= 81 )
replace SOLVN30A = . if (SOLVN30A >= 81 )
replace AMLNT30A = . if (AMLNT30A >= 81 )
replace ETHER30A = . if (ETHER30A >= 81 )
replace NOX30A = . if (NOX30A >= 81 )
replace CLFL30A = . if (CLFL30A >= 81 )
replace INNEW30A = . if (INNEW30A >= 981 )
replace INNEW30B = . if (INNEW30B >= 981 )
replace INNEW30C = . if (INNEW30C >= 981 )
replace INNEW30D = . if (INNEW30D >= 981 )
replace INNEW30E = . if (INNEW30E >= 981 )
replace IN30NOSP = . if (IN30NOSP >= 81 )
replace INH30NO = . if (INH30NO >= 81 )
replace INHDY30A = . if (INHDY30A >= 81 )
replace INHYRFRQ = . if (INHYRFRQ >= 81 )
replace INHPO = . if (INHPO >= 81 )
replace INHQNC1 = . if (INHQNC1 >= 81 )
replace INHQNC2 = . if (INHQNC2 >= 81 )
replace INHQNC3 = . if (INHQNC3 >= 81 )
replace INHQNC4 = . if (INHQNC4 >= 81 )
replace INHQNC5 = . if (INHQNC5 >= 81 )
replace INHQNC6 = . if (INHQNC6 >= 81 )
replace INHQNC7 = . if (INHQNC7 >= 81 )
replace INHQNC8 = . if (INHQNC8 >= 81 )
replace INHQNC10 = . if (INHQNC10 >= 81 )
replace INHANSY = . if (INHANSY >= 81 )
replace COCOPP = . if (COCOPP >= 981 )
replace COCAGE = . if (COCAGE >= 981 )
replace COCTOT = . if (COCTOT >= 81 )
replace COCREC = . if (COCREC >= 81 )
replace COCUS30A = . if (COCUS30A >= 81 )
replace COCAM30A = . if (COCAM30A >= 81 )
replace CCFRIEND = . if (CCFRIEND >= 81 )
replace CCDEALER = . if (CCDEALER >= 81 )
replace CCOTHSHR = . if (CCOTHSHR >= 81 )
replace CCGIVEN = . if (CCGIVEN >= 81 )
replace CCTRGOOD = . if (CCTRGOOD >= 81 )
replace CCTRSERV = . if (CCTRSERV >= 81 )
replace CCSTOLE = . if (CCSTOLE >= 81 )
replace CCTRICK = . if (CCTRICK >= 81 )
replace CCOBTNON = . if (CCOBTNON >= 81 )
replace COCBUCK = . if (COCBUCK >= 9981 )
replace COCYRFRQ = . if (COCYRFRQ >= 81 )
replace COCSNIFF = . if (COCSNIFF >= 81 )
replace COCSWAL = . if (COCSWAL >= 81 )
replace COCIV = . if (COCIV >= 81 )
replace FREEBASE = . if (FREEBASE >= 81 )
replace COCWAY = . if (COCWAY >= 81 )
replace CONDLREC = . if (CONDLREC >= 81 )
replace CCLFDALY = . if (CCLFDALY >= 81 )
replace CRAKREC = . if (CRAKREC >= 81 )
replace CRKAM30A = . if (CRKAM30A >= 981 )
replace CKFRIEND = . if (CKFRIEND >= 81 )
replace CKDEALER = . if (CKDEALER >= 81 )
replace CKOTHSHR = . if (CKOTHSHR >= 81 )
replace CKGIVEN = . if (CKGIVEN >= 81 )
replace CKTRGOOD = . if (CKTRGOOD >= 81 )
replace CKTRSERV = . if (CKTRSERV >= 81 )
replace CKSTOLE = . if (CKSTOLE >= 81 )
replace CKTRICK = . if (CKTRICK >= 81 )
replace CKOBTNON = . if (CKOBTNON >= 81 )
replace CRAKBUCK = . if (CRAKBUCK >= 9981 )
replace CKLFDALY = . if (CKLFDALY >= 81 )
replace HALREAD = . if (HALREAD >= 81 )
replace LSD = . if (LSD >= 81 )
replace PEYOTE = . if (PEYOTE >= 81 )
replace MESC = . if (MESC >= 81 )
replace PSILCY = . if (PSILCY >= 81 )
replace PCP = . if (PCP >= 81 )
replace ECSTASY = . if (ECSTASY >= 81 )
replace HALNEWA = . if (HALNEWA >= 981 )
replace HALNEWB = . if (HALNEWB >= 981 )
replace HALNEWC = . if (HALNEWC >= 981 )
replace HALNEWD = . if (HALNEWD >= 981 )
replace HALNEWE = . if (HALNEWE >= 981 )
replace HALNOSP = . if (HALNOSP >= 81 )
replace HALDKNAM = . if (HALDKNAM >= 81 )
replace HALLOPP = . if (HALLOPP >= 81 )
replace HALLAGE = . if (HALLAGE >= 81 )
replace HALLTOT = . if (HALLTOT >= 81 )
replace HALLREC = . if (HALLREC >= 81 )
replace HAL30USE = . if (HAL30USE >= 81 )
replace HALYRFRQ = . if (HALYRFRQ >= 81 )
replace PCPREC = . if (PCPREC >= 81 )
replace HERREAD = . if (HERREAD >= 81 )
replace HEROPP = . if (HEROPP >= 81 )
replace HERAGE = . if (HERAGE >= 81 )
replace HERTOT = . if (HERTOT >= 81 )
replace HERREC = . if (HERREC >= 81 )
replace HER30USE = . if (HER30USE >= 81 )
replace HERNEEDL = . if (HERNEEDL >= 81 )
replace HRNDLREC = . if (HRNDLREC >= 81 )
replace HERSMOKE = . if (HERSMOKE >= 81 )
replace HRSMKREC = . if (HRSMKREC >= 81 )
replace HERSNIFF = . if (HERSNIFF >= 81 )
replace HRSNFREC = . if (HRSNFREC >= 81 )
replace DRGREAD = . if (DRGREAD >= 81 )
replace CDCIG = . if (CDCIG >= 81 )
replace CDALC = . if (CDALC >= 81 )
replace CDSED = . if (CDSED >= 81 )
replace CDTRAN = . if (CDTRAN >= 81 )
replace CDSTM = . if (CDSTM >= 81 )
replace CDANAL = . if (CDANAL >= 81 )
replace CDMJ = . if (CDMJ >= 81 )
replace CDINH = . if (CDINH >= 81 )
replace CDCOC = . if (CDCOC >= 81 )
replace CDHALL = . if (CDHALL >= 81 )
replace CDHER = . if (CDHER >= 81 )
replace CDOTHOP = . if (CDOTHOP >= 81 )
replace CDNONE = . if (CDNONE >= 81 )
replace UCDCIG = . if (UCDCIG >= 81 )
replace UCDALC = . if (UCDALC >= 81 )
replace UCDSED = . if (UCDSED >= 81 )
replace UCDTRAN = . if (UCDTRAN >= 81 )
replace UCDSTM = . if (UCDSTM >= 81 )
replace UCDANAL = . if (UCDANAL >= 81 )
replace UCDMJ = . if (UCDMJ >= 81 )
replace UCDINH = . if (UCDINH >= 81 )
replace UCDCOC = . if (UCDCOC >= 81 )
replace UCDHALL = . if (UCDHALL >= 81 )
replace UCDHER = . if (UCDHER >= 81 )
replace UCDOTHOP = . if (UCDOTHOP >= 81 )
replace UCDNONE = . if (UCDNONE >= 81 )
replace EFFCIG = . if (EFFCIG >= 81 )
replace EFFALC = . if (EFFALC >= 81 )
replace EFFSED = . if (EFFSED >= 81 )
replace EFFTRAN = . if (EFFTRAN >= 81 )
replace EFFSTM = . if (EFFSTM >= 81 )
replace EFFANAL = . if (EFFANAL >= 81 )
replace EFFMJ = . if (EFFMJ >= 81 )
replace EFFINH = . if (EFFINH >= 81 )
replace EFFCOC = . if (EFFCOC >= 81 )
replace EFFHALL = . if (EFFHALL >= 81 )
replace EFFHER = . if (EFFHER >= 81 )
replace EFFOTHOP = . if (EFFOTHOP >= 81 )
replace EFFNONE = . if (EFFNONE >= 81 )
replace UDAYCIG = . if (UDAYCIG >= 81 )
replace UDAYALC = . if (UDAYALC >= 81 )
replace UDAYSED = . if (UDAYSED >= 81 )
replace UDAYTRAN = . if (UDAYTRAN >= 81 )
replace UDAYSTM = . if (UDAYSTM >= 81 )
replace UDAYANAL = . if (UDAYANAL >= 81 )
replace UDAYMJ = . if (UDAYMJ >= 81 )
replace UDAYINH = . if (UDAYINH >= 81 )
replace UDAYCOC = . if (UDAYCOC >= 81 )
replace UDAYHALL = . if (UDAYHALL >= 81 )
replace UDAYHER = . if (UDAYHER >= 81 )
replace UDAYOTH = . if (UDAYOTH >= 81 )
replace UDAYNONE = . if (UDAYNONE >= 81 )
replace DEPCIG = . if (DEPCIG >= 81 )
replace DEPALC = . if (DEPALC >= 81 )
replace DEPSED = . if (DEPSED >= 81 )
replace DEPTRAN = . if (DEPTRAN >= 81 )
replace DEPSTM = . if (DEPSTM >= 81 )
replace DEPANAL = . if (DEPANAL >= 81 )
replace DEPMJ = . if (DEPMJ >= 81 )
replace DEPINH = . if (DEPINH >= 81 )
replace DEPCOC = . if (DEPCOC >= 81 )
replace DEPHALL = . if (DEPHALL >= 81 )
replace DEPHER = . if (DEPHER >= 81 )
replace DEPOTHOP = . if (DEPOTHOP >= 81 )
replace DEPNONE = . if (DEPNONE >= 81 )
replace WSCIG = . if (WSCIG >= 81 )
replace WSALC = . if (WSALC >= 81 )
replace WSSED = . if (WSSED >= 81 )
replace WSTRAN = . if (WSTRAN >= 81 )
replace WSSTM = . if (WSSTM >= 81 )
replace WSANAL = . if (WSANAL >= 81 )
replace WSMJ = . if (WSMJ >= 81 )
replace WSINH = . if (WSINH >= 81 )
replace WSCOC = . if (WSCOC >= 81 )
replace WSHALL = . if (WSHALL >= 81 )
replace WSHER = . if (WSHER >= 81 )
replace WSOTHOP = . if (WSOTHOP >= 81 )
replace WSNONE = . if (WSNONE >= 81 )
replace NDLREAD = . if (NDLREAD >= 81 )
replace GNNDLLIF = . if (GNNDLLIF >= 81 )
replace GNNDLREC = . if (GNNDLREC >= 81 )
replace GNNDLSED = . if (GNNDLSED >= 81 )
replace GNNDLTRA = . if (GNNDLTRA >= 81 )
replace GNNDLSTM = . if (GNNDLSTM >= 81 )
replace GNNDLANL = . if (GNNDLANL >= 81 )
replace GNNDLINH = . if (GNNDLINH >= 81 )
replace GNNDLCOC = . if (GNNDLCOC >= 81 )
replace GNNDLHAL = . if (GNNDLHAL >= 81 )
replace GNNDLHER = . if (GNNDLHER >= 81 )
replace GNNDLOPT = . if (GNNDLOPT >= 81 )
replace GNNDLSTR = . if (GNNDLSTR >= 81 )
replace GNNDLNON = . if (GNNDLNON >= 81 )
replace GNNDLSH1 = . if (GNNDLSH1 >= 81 )
replace GNNDLSH2 = . if (GNNDLSH2 >= 81 )
replace SPTREAD = . if (SPTREAD >= 81 )
replace DRUGTEST = . if (DRUGTEST >= 81 )
replace TESTPOS = . if (TESTPOS >= 81 )
replace ICELIFE = . if (ICELIFE >= 81 )
replace ICEREC = . if (ICEREC >= 81 )
replace STEROPP = . if (STEROPP >= 981 )
replace STERAGE = . if (STERAGE >= 981 )
replace STERTOT = . if (STERTOT >= 81 )
replace STERREC = . if (STERREC >= 81 )
replace SPNEWA = . if (SPNEWA >= 981 )
replace SPNEWB = . if (SPNEWB >= 981 )
replace SPNEWC = . if (SPNEWC >= 981 )
replace SPNEWD = . if (SPNEWD >= 981 )
replace SPNEWE = . if (SPNEWE >= 981 )
replace BOOKED = . if (BOOKED >= 81 )
replace NOBOOKYR = . if (NOBOOKYR >= 81 )
replace BKLARCNY = . if (BKLARCNY >= 81 )
replace BKBURGL = . if (BKBURGL >= 81 )
replace BKAGASLT = . if (BKAGASLT >= 81 )
replace BKSMASLT = . if (BKSMASLT >= 81 )
replace BKMVTHFT = . if (BKMVTHFT >= 81 )
replace BKROB = . if (BKROB >= 81 )
replace BKRAPE = . if (BKRAPE >= 81 )
replace BKMURDER = . if (BKMURDER >= 81 )
replace BKARSON = . if (BKARSON >= 81 )
replace BKDRVINF = . if (BKDRVINF >= 81 )
replace BKDRUNK = . if (BKDRUNK >= 81 )
replace BKDRUG = . if (BKDRUG >= 81 )
replace BKPROS = . if (BKPROS >= 81 )
replace BKVANDAL = . if (BKVANDAL >= 81 )
replace BKOTHOFF = . if (BKOTHOFF >= 81 )
replace NOTBKED = . if (NOTBKED >= 81 )
replace PROBATON = . if (PROBATON >= 81 )
replace PAROLE = . if (PAROLE >= 81 )
replace STRSTEAL = . if (STRSTEAL >= 81 )
replace OTHSTEAL = . if (OTHSTEAL >= 81 )
replace DAMAGE = . if (DAMAGE >= 81 )
replace CARSTEAL = . if (CARSTEAL >= 81 )
replace FORCEMON = . if (FORCEMON >= 81 )
replace BREAKIN = . if (BREAKIN >= 81 )
replace PHYFIGHT = . if (PHYFIGHT >= 81 )
replace HURTBAD = . if (HURTBAD >= 81 )
replace GUNMONEY = . if (GUNMONEY >= 81 )
replace DRUNKDRV = . if (DRUNKDRV >= 81 )
replace SOLDDRUG = . if (SOLDDRUG >= 81 )
replace OTHDOING = . if (OTHDOING >= 81 )
replace OTHDOSP1 = . if (OTHDOSP1 >= 81 )
replace OTHDOSP2 = . if (OTHDOSP2 >= 81 )
replace DEXREAD = . if (DEXREAD >= 81 )
replace NOBOOZYR = . if (NOBOOZYR >= 81 )
replace ALCAGGR = . if (ALCAGGR >= 81 )
replace ALCARGUM = . if (ALCARGUM >= 81 )
replace ALCABSNT = . if (ALCABSNT >= 81 )
replace ALCHIGH = . if (ALCHIGH >= 81 )
replace ALCJOB = . if (ALCJOB >= 81 )
replace ALCMATCD = . if (ALCMATCD >= 81 )
replace ALCRELCD = . if (ALCRELCD >= 81 )
replace ALCFRDCD = . if (ALCFRDCD >= 81 )
replace ALCTOSS = . if (ALCTOSS >= 81 )
replace ALCHOLIC = . if (ALCHOLIC >= 81 )
replace ALCDRUNK = . if (ALCDRUNK >= 81 )
replace ALCINTOX = . if (ALCINTOX >= 81 )
replace ALCREM = . if (ALCREM >= 81 )
replace ALCQUICK = . if (ALCQUICK >= 81 )
replace ALCMORN = . if (ALCMORN >= 81 )
replace ALCSHOOK = . if (ALCSHOOK >= 81 )
replace ALCALONE = . if (ALCALONE >= 81 )
replace ALCBRKPM = . if (ALCBRKPM >= 81 )
replace ALCMJ = . if (ALCMJ >= 81 )
replace ALCCOC = . if (ALCCOC >= 81 )
replace ALCOPT = . if (ALCOPT >= 81 )
replace ALCHAL = . if (ALCHAL >= 81 )
replace ALCINH = . if (ALCINH >= 81 )
replace ALCANAL = . if (ALCANAL >= 81 )
replace ALCTRAN = . if (ALCTRAN >= 81 )
replace ALCSTM = . if (ALCSTM >= 81 )
replace ALCSED = . if (ALCSED >= 81 )
replace AS13NONE = . if (AS13NONE >= 81 )
replace DRDEPRSS = . if (DRDEPRSS >= 81 )
replace DEPDRG1A = . if (DEPDRG1A >= 981 )
replace DEPDRG2A = . if (DEPDRG2A >= 981 )
replace DEPDRG3A = . if (DEPDRG3A >= 981 )
replace DEPDRG4A = . if (DEPDRG4A >= 981 )
replace DEPDRG5A = . if (DEPDRG5A >= 981 )
replace DRARGUM = . if (DRARGUM >= 81 )
replace ARGDRG1A = . if (ARGDRG1A >= 981 )
replace ARGDRG2A = . if (ARGDRG2A >= 981 )
replace ARGDRG3A = . if (ARGDRG3A >= 981 )
replace ARGDRG4A = . if (ARGDRG4A >= 981 )
replace ARGDRG5A = . if (ARGDRG5A >= 981 )
replace DRALONE = . if (DRALONE >= 81 )
replace ALNDRG1A = . if (ALNDRG1A >= 981 )
replace ALNDRG2A = . if (ALNDRG2A >= 981 )
replace ALNDRG3A = . if (ALNDRG3A >= 981 )
replace ALNDRG4A = . if (ALNDRG4A >= 981 )
replace ALNDRG5A = . if (ALNDRG5A >= 981 )
replace DRANX = . if (DRANX >= 81 )
replace ANXDRG1A = . if (ANXDRG1A >= 981 )
replace ANXDRG2A = . if (ANXDRG2A >= 981 )
replace ANXDRG3A = . if (ANXDRG3A >= 981 )
replace ANXDRG4A = . if (ANXDRG4A >= 981 )
replace ANXDRG5A = . if (ANXDRG5A >= 981 )
replace DRHEALTH = . if (DRHEALTH >= 81 )
replace HLTDRG1A = . if (HLTDRG1A >= 981 )
replace HLTDRG2A = . if (HLTDRG2A >= 981 )
replace HLTDRG3A = . if (HLTDRG3A >= 981 )
replace HLTDRG4A = . if (HLTDRG4A >= 981 )
replace HLTDRG5A = . if (HLTDRG5A >= 981 )
replace DRNTHINK = . if (DRNTHINK >= 81 )
replace NTKDRG1A = . if (NTKDRG1A >= 981 )
replace NTKDRG2A = . if (NTKDRG2A >= 981 )
replace NTKDRG3A = . if (NTKDRG3A >= 981 )
replace NTKDRG4A = . if (NTKDRG4A >= 981 )
replace NTKDRG5A = . if (NTKDRG5A >= 981 )
replace DRUPSET = . if (DRUPSET >= 81 )
replace UPSDRG1A = . if (UPSDRG1A >= 981 )
replace UPSDRG2A = . if (UPSDRG2A >= 981 )
replace UPSDRG3A = . if (UPSDRG3A >= 981 )
replace UPSDRG4A = . if (UPSDRG4A >= 981 )
replace UPSDRG5A = . if (UPSDRG5A >= 981 )
replace DRLSWORK = . if (DRLSWORK >= 81 )
replace LSWDRG1A = . if (LSWDRG1A >= 981 )
replace LSWDRG2A = . if (LSWDRG2A >= 981 )
replace LSWDRG3A = . if (LSWDRG3A >= 981 )
replace LSWDRG4A = . if (LSWDRG4A >= 981 )
replace LSWDRG5A = . if (LSWDRG5A >= 981 )
replace DRSUSPIC = . if (DRSUSPIC >= 81 )
replace SSPDRG1A = . if (SSPDRG1A >= 981 )
replace SSPDRG2A = . if (SSPDRG2A >= 981 )
replace SSPDRG3A = . if (SSPDRG3A >= 981 )
replace SSPDRG4A = . if (SSPDRG4A >= 981 )
replace SSPDRG5A = . if (SSPDRG5A >= 981 )
replace DRCOPE = . if (DRCOPE >= 81 )
replace CPEDRG1A = . if (CPEDRG1A >= 981 )
replace CPEDRG2A = . if (CPEDRG2A >= 981 )
replace CPEDRG3A = . if (CPEDRG3A >= 981 )
replace CPEDRG4A = . if (CPEDRG4A >= 981 )
replace CPEDRG5A = . if (CPEDRG5A >= 981 )
replace DREMGMED = . if (DREMGMED >= 81 )
replace EMDRG1A = . if (EMDRG1A >= 981 )
replace EMDRG2A = . if (EMDRG2A >= 981 )
replace EMDRG3A = . if (EMDRG3A >= 981 )
replace EMDRG4A = . if (EMDRG4A >= 981 )
replace EMDRG5A = . if (EMDRG5A >= 981 )
replace DRTRMT = . if (DRTRMT >= 81 )
replace TMTDRG1A = . if (TMTDRG1A >= 981 )
replace TMTDRG2A = . if (TMTDRG2A >= 981 )
replace TMTDRG3A = . if (TMTDRG3A >= 981 )
replace TMTDRG4A = . if (TMTDRG4A >= 981 )
replace TMTDRG5A = . if (TMTDRG5A >= 981 )
replace DRDRVUN = . if (DRDRVUN >= 81 )
replace DRVDRG1A = . if (DRVDRG1A >= 981 )
replace DRVDRG2A = . if (DRVDRG2A >= 981 )
replace DRVDRG3A = . if (DRVDRG3A >= 981 )
replace DRVDRG4A = . if (DRVDRG4A >= 981 )
replace DRVDRG5A = . if (DRVDRG5A >= 981 )
replace TMTREAD = . if (TMTREAD >= 81 )
replace EMPDRUG = . if (EMPDRUG >= 81 )
replace CIGHELP = . if (CIGHELP >= 81 )
replace DRNKHELP = . if (DRNKHELP >= 81 )
replace TRMTHELP = . if (TRMTHELP >= 81 )
replace TRMTEMRG = . if (TRMTEMRG >= 81 )
replace TRMTHOSP = . if (TRMTHOSP >= 81 )
replace TRMTDOC = . if (TRMTDOC >= 81 )
replace TRMTTRMT = . if (TRMTTRMT >= 81 )
replace TRMTMHC = . if (TRMTMHC >= 81 )
replace TRMTSHG = . if (TRMTSHG >= 81 )
replace TRMTSOP = . if (TRMTSOP >= 81 )
replace TRMTSP = . if (TRMTSP >= 81 )
replace TRMTREC = . if (TRMTREC >= 81 )
replace NRTXLIFE = . if (NRTXLIFE >= 981 )
replace NOTRMT = . if (NOTRMT >= 81 )
replace TXEMRG = . if (TXEMRG >= 81 )
replace TXHOSP = . if (TXHOSP >= 81 )
replace TXDOC = . if (TXDOC >= 81 )
replace TXTRMT = . if (TXTRMT >= 81 )
replace TXMHC = . if (TXMHC >= 81 )
replace TXSHG = . if (TXSHG >= 81 )
replace TXSOP = . if (TXSOP >= 81 )
replace TXSP = . if (TXSP >= 81 )
replace TRMTLIFE = . if (TRMTLIFE >= 81 )
replace TRMTRESP = . if (TRMTRESP >= 81 )
replace TRMTFEAR = . if (TRMTFEAR >= 81 )
replace TRMTCOST = . if (TRMTCOST >= 81 )
replace TRMTEVNT = . if (TRMTEVNT >= 81 )
replace TRMTPR = . if (TRMTPR >= 81 )
replace TRMTHLTH = . if (TRMTHLTH >= 81 )
replace TRMTJOB = . if (TRMTJOB >= 81 )
replace TRMTJAIL = . if (TRMTJAIL >= 81 )
replace TRMTSERV = . if (TRMTSERV >= 81 )
replace TRMTBQD = . if (TRMTBQD >= 81 )
replace TRMTDNA = . if (TRMTDNA >= 81 )
replace TRMTSOR = . if (TRMTSOR >= 81 )
replace TRMTRSP = . if (TRMTRSP >= 81 )
replace TRMTDRGA = . if (TRMTDRGA >= 981 )
replace TRMTDRGB = . if (TRMTDRGB >= 981 )
replace TRMTDRGC = . if (TRMTDRGC >= 981 )
replace TRMTDRGD = . if (TRMTDRGD >= 981 )
replace TRMTDRGE = . if (TRMTDRGE >= 981 )
replace TRMTOUTC = . if (TRMTOUTC >= 81 )
replace TMTPHI = . if (TMTPHI >= 81 )
replace TMTPSAVE = . if (TMTPSAVE >= 81 )
replace TMTPFMLY = . if (TMTPFMLY >= 81 )
replace TMTPEMPR = . if (TMTPEMPR >= 81 )
replace TMTPMEDI = . if (TMTPMEDI >= 81 )
replace TMTPFREE = . if (TMTPFREE >= 81 )
replace TMTPOTH = . if (TMTPOTH >= 81 )
replace TMTPASP = . if (TMTPASP >= 81 )
replace RSKPKCIG = . if (RSKPKCIG >= 81 )
replace RSKTRYMJ = . if (RSKTRYMJ >= 81 )
replace RSKMJOCC = . if (RSKMJOCC >= 81 )
replace RSKMJREG = . if (RSKMJREG >= 81 )
replace RKTRYPCP = . if (RKTRYPCP >= 81 )
replace RKPCPREG = . if (RKPCPREG >= 81 )
replace RKTRYHER = . if (RKTRYHER >= 81 )
replace RKHERREG = . if (RKHERREG >= 81 )
replace RKTRYCOC = . if (RKTRYCOC >= 81 )
replace RKCOCOCC = . if (RKCOCOCC >= 81 )
replace RKCOCREG = . if (RKCOCREG >= 81 )
replace RKCRKOCC = . if (RKCRKOCC >= 81 )
replace RKANSOCC = . if (RKANSOCC >= 81 )
replace RKANSREG = . if (RKANSREG >= 81 )
replace RK2DRINK = . if (RK2DRINK >= 81 )
replace RK5DRINK = . if (RK5DRINK >= 81 )
replace RSKBINGE = . if (RSKBINGE >= 81 )
replace RSKDIFMJ = . if (RSKDIFMJ >= 81 )
replace RKDIFLSD = . if (RKDIFLSD >= 81 )
replace RKDIFPCP = . if (RKDIFPCP >= 81 )
replace RKDIFCOC = . if (RKDIFCOC >= 81 )
replace RKDIFHER = . if (RKDIFHER >= 81 )
replace RSKSELL = . if (RSKSELL >= 81 )
replace RKNEIDRN = . if (RKNEIDRN >= 81 )
replace RKNEISEL = . if (RKNEISEL >= 81 )
replace HIGHBP = . if (HIGHBP >= 81 )
replace BPMED = . if (BPMED >= 81 )
replace WALKPAIN = . if (WALKPAIN >= 81 )
replace TIMEPAIN = . if (TIMEPAIN >= 81 )
replace UPSHOR = . if (UPSHOR >= 81 )
replace ASTHMA = . if (ASTHMA >= 81 )
replace TRPSYCH = . if (TRPSYCH >= 81 )
replace HEART = . if (HEART >= 81 )
replace FLU = . if (FLU >= 81 )
replace ALLERG = . if (ALLERG >= 94 )
replace HOSPYR = . if (HOSPYR >= 81 )
replace SOREYR = . if (SOREYR >= 81 )
replace RUNNYYR = . if (RUNNYYR >= 81 )
replace COUGHYR = . if (COUGHYR >= 81 )
replace PHLEGMYR = . if (PHLEGMYR >= 81 )
replace HEALTHYR = . if (HEALTHYR >= 81 )
replace FLTEAT = . if (FLTEAT >= 81 )
replace FLTMIND = . if (FLTMIND >= 81 )
replace FLTDEPRS = . if (FLTDEPRS >= 81 )
replace FLTEFFRT = . if (FLTEFFRT >= 81 )
replace FLTSLEEP = . if (FLTSLEEP >= 81 )
replace FLTSAD = . if (FLTSAD >= 81 )
replace FLTGOING = . if (FLTGOING >= 81 )
replace MARITAL = . if (MARITAL >= 81 )
replace NOMARR = . if (NOMARR >= 81 )
replace WORKSTAT = . if (WORKSTAT >= 81 )
replace PAYMO = . if (PAYMO >= 89 )
replace PAYYR = . if (PAYYR >= 981 )
replace NO5JOB = . if (NO5JOB >= 94 )
replace WORKDAYS = . if (WORKDAYS >= 81 )
replace WORKBLAH = . if (WORKBLAH >= 81 )
replace CWE = . if (CWE >= 81 )
replace CWESC1 = . if (CWESC1 >= 981 )
replace CWESC2 = . if (CWESC2 >= 981 )
replace FULLPART = . if (FULLPART >= 81 )
replace EDUC = . if (EDUC >= 81 )
replace GRADHS = . if (GRADHS >= 81 )
replace DIPLOMA = . if (DIPLOMA >= 81 )
replace ENROLLD = . if (ENROLLD >= 81 )
replace SCHPLANS = . if (SCHPLANS >= 81 )
replace STUDENT = . if (STUDENT >= 81 )
replace SCHDAYS = . if (SCHDAYS >= 81 )
replace SKIPPED = . if (SKIPPED >= 81 )
replace MILES = . if (MILES >= 99981 )
replace ACCID = . if (ACCID >= 81 )
replace TOTPEOP = . if (TOTPEOP >= 81 )
replace MOTHER = . if (MOTHER >= 81 )
replace FATHER = . if (FATHER >= 81 )
replace STEPMOM = . if (STEPMOM >= 81 )
replace STEPDAD = . if (STEPDAD >= 81 )
replace SPOUSE = . if (SPOUSE >= 81 )
replace INLAW = . if (INLAW >= 81 )
replace OWNCHILD = . if (OWNCHILD >= 81 )
replace STEPCHLD = . if (STEPCHLD >= 81 )
replace BROSIS = . if (BROSIS >= 81 )
replace OTHREL = . if (OTHREL >= 81 )
replace FRIENDS = . if (FRIENDS >= 81 )
replace OTHERNON = . if (OTHERNON >= 81 )
replace MOVDAWAY = . if (MOVDAWAY >= 81 )
replace DORM = . if (DORM >= 81 )
replace MILBASE = . if (MILBASE >= 81 )
replace HOSP = . if (HOSP >= 81 )
replace OTHGPH = . if (OTHGPH >= 81 )
replace OTHGPHSP = . if (OTHGPHSP >= 81 )
replace SERVICE = . if (SERVICE >= 81 )
replace MILSTAT = . if (MILSTAT >= 81 )
replace TELNO = . if (TELNO >= 81 )
replace MOVES = . if (MOVES >= 81 )
replace PROXABLE = . if (PROXABLE >= 81 )
replace PROXYREL = . if (PROXYREL >= 981 )
replace PROXHOME = . if (PROXHOME >= 81 )
replace PROXJOIN = . if (PROXJOIN >= 81 )
replace MEDICARE = . if (MEDICARE >= 81 )
replace MEDICAID = . if (MEDICAID >= 81 )
replace CHAMPUS = . if (CHAMPUS >= 81 )
replace PRVHLTIN = . if (PRVHLTIN >= 81 )
replace OWNHLTIN = . if (OWNHLTIN >= 81 )
replace GRPHLTIN = . if (GRPHLTIN >= 81 )
replace HLTINALC = . if (HLTINALC >= 81 )
replace HLTINDRG = . if (HLTINDRG >= 81 )
replace HLTINMNT = . if (HLTINMNT >= 81 )
replace WHOANSHI = . if (WHOANSHI >= 981 )
replace JOB = . if (JOB >= 81 )
replace HOURS = . if (HOURS >= 981 )
replace WORK = . if (WORK >= 81 )
replace WAG1 = . if (WAG1 >= 81 )
replace AWAG1 = . if (AWAG1 >= 999981 )
replace WEEKS = . if (WEEKS >= 81 )
replace SOC1 = . if (SOC1 >= 81 )
replace ASOC1 = . if (ASOC1 >= 999981 )
replace SSI1 = . if (SSI1 >= 81 )
replace ASSI1 = . if (ASSI1 >= 999981 )
replace PUB1 = . if (PUB1 >= 81 )
replace AFDC1 = . if (AFDC1 >= 81 )
replace WEL1 = . if (WEL1 >= 81 )
replace AWEL1 = . if (AWEL1 >= 999981 )
replace INT1 = . if (INT1 >= 81 )
replace AINT1 = . if (AINT1 >= 999981 )
replace CHD1 = . if (CHD1 >= 81 )
replace ACHD1 = . if (ACHD1 >= 999981 )
replace OTH1 = . if (OTH1 >= 81 )
replace AOTH1 = . if (AOTH1 >= 999981 )
replace FAMLYRES = . if (FAMLYRES >= 81 )
replace WAG2 = . if (WAG2 >= 81 )
replace AWAG2 = . if (AWAG2 >= 999981 )
replace SOC2 = . if (SOC2 >= 81 )
replace ASOC2 = . if (ASOC2 >= 999981 )
replace SSI2 = . if (SSI2 >= 81 )
replace ASSI2 = . if (ASSI2 >= 999981 )
replace PUB2 = . if (PUB2 >= 81 )
replace AFDC2 = . if (AFDC2 >= 81 )
replace WEL2 = . if (WEL2 >= 81 )
replace AWEL2 = . if (AWEL2 >= 999981 )
replace INT2 = . if (INT2 >= 81 )
replace AINT2 = . if (AINT2 >= 999981 )
replace CHD2 = . if (CHD2 >= 81 )
replace ACHD2 = . if (ACHD2 >= 999981 )
replace OTH2 = . if (OTH2 >= 81 )
replace AOTH2 = . if (AOTH2 >= 999981 )
replace WHOANSIN = . if (WHOANSIN >= 981 )
replace FSTAMP = . if (FSTAMP >= 81 )
replace PEOPFD = . if (PEOPFD >= 81 )
replace FOOD = . if (FOOD >= 81 )
replace AFOOD = . if (AFOOD >= 999981 )
replace BHOUR = . if (BHOUR >= 81 )
replace BMIN = . if (BMIN >= 81 )
replace BAP = . if (BAP >= 81 )
replace EAP = . if (EAP >= 81 )
replace LANGVER = . if (LANGVER >= 81 )
replace UNDINT = . if (UNDINT >= 81 )
replace COOPINT = . if (COOPINT >= 81 )
replace PRIVACY = . if (PRIVACY >= 81 )
replace PPRES = . if (PPRES >= 81 )
replace SPRES = . if (SPRES >= 81 )
replace PARPRES = . if (PARPRES >= 81 )
replace OARPRES = . if (OARPRES >= 81 )
replace OAPRES = . if (OAPRES >= 81 )
replace CPRES = . if (CPRES >= 81 )
replace OPRESNSP = . if (OPRESNSP >= 81 )
replace OPRESSPA = . if (OPRESSPA >= 981 )
replace OPRESSPB = . if (OPRESSPB >= 981 )
replace WHOMARKD = . if (WHOMARKD >= 81 )
replace FAMSKIP = . if (FAMSKIP >= 81 )
replace GQTYPE = . if (GQTYPE == 9)
replace DC = . if (DC >= 9 )
replace CHICAGO = . if (CHICAGO >= 9 )
replace DENVER = . if (DENVER >= 9 )
replace LA = . if (LA >= 9 )
replace MIAMI = . if (MIAMI >= 9 )
replace NEWYORK = . if (NEWYORK >= 9 )
replace URBARE = . if (URBARE >= 9 )
replace METRO = . if (METRO >= 9 )
replace IRHOGRP = . if (IRHOGRP >= 81 )
replace IIHOGRP = . if (IIHOGRP >= 9 )
replace IRHOGRP2 = . if (IRHOGRP2 >= 81 )
replace IIHOGRP2 = . if (IIHOGRP2 >= 9 )
replace IRMARIT = . if (IRMARIT >= 81 )
replace IIMARIT = . if (IIMARIT >= 9 )
replace IRWORKST = . if (IRWORKST >= 81 )
replace IIAWAG1 = . if (IIAWAG1 >= 9 )
replace IIASOC1 = . if (IIASOC1 >= 9 )
replace IIASSI1 = . if (IIASSI1 >= 9 )
replace IIAWEL1 = . if (IIAWEL1 >= 9 )
replace IIAINT1 = . if (IIAINT1 >= 9 )
replace IIACHD1 = . if (IIACHD1 >= 9 )
replace IIAOTH1 = . if (IIAOTH1 >= 9 )
replace IIWAG2 = . if (IIWAG2 >= 9 )
replace IIAWAG2 = . if (IIAWAG2 >= 9 )
replace IISOC2 = . if (IISOC2 >= 9 )
replace IIASOC2 = . if (IIASOC2 >= 9 )
replace IISSI2 = . if (IISSI2 >= 9 )
replace IIASSI2 = . if (IIASSI2 >= 9 )
replace IIWEL2 = . if (IIWEL2 >= 9 )
replace IIAWEL2 = . if (IIAWEL2 >= 9 )
replace IIINT2 = . if (IIINT2 >= 9 )
replace IIAINT2 = . if (IIAINT2 >= 9 )
replace IICHD2 = . if (IICHD2 >= 9 )
replace IIACHD2 = . if (IIACHD2 >= 9 )
replace IIOTH2 = . if (IIOTH2 >= 9 )
replace IIAOTH2 = . if (IIAOTH2 >= 9 )
replace IIAFOOD = . if (IIAFOOD >= 9 )
replace IRPEOP = . if (IRPEOP >= 81 )
replace IRALCRC = . if (IRALCRC >= 9 )
replace IRMJRC = . if (IRMJRC >= 9 )
replace IRCOCRC = . if (IRCOCRC >= 9 )
replace IRSEDRC = . if (IRSEDRC >= 9 )
replace IRTRNRC = . if (IRTRNRC >= 9 )
replace IRSTMRC = . if (IRSTMRC >= 9 )
replace IRANLRC = . if (IRANLRC >= 9 )
replace IRCIGRC = . if (IRCIGRC >= 9 )
replace IROTBRC = . if (IROTBRC >= 9 )
replace IRINHRC = . if (IRINHRC >= 9 )
replace IRCRKRC = . if (IRCRKRC >= 9 )
replace IRHALRC = . if (IRHALRC >= 9 )
replace IRHERRC = . if (IRHERRC >= 9 )
replace IRPCPRC = . if (IRPCPRC >= 9 )
replace IRICERC = . if (IRICERC >= 9 )
replace IRSTRRC = . if (IRSTRRC >= 9 )
replace IRALCFQ = . if (IRALCFQ >= 9 )
replace IRMJFQ = . if (IRMJFQ >= 9 )
replace IRCOCFQ = . if (IRCOCFQ >= 9 )
replace IRSEDFQ = . if (IRSEDFQ >= 9 )
replace IRTRNFQ = . if (IRTRNFQ >= 9 )
replace IRSTMFQ = . if (IRSTMFQ >= 9 )
replace IRANLFQ = . if (IRANLFQ >= 9 )
replace IROTBFQ = . if (IROTBFQ >= 9 )
replace IRINHFQ = . if (IRINHFQ >= 9 )
replace IRHALFQ = . if (IRHALFQ >= 9 )
replace INDCAT = . if (INDCAT >= 81 )
replace TOTCAT = . if (TOTCAT >= 81 )
replace NEEDLREC = . if (NEEDLREC >= 81 )
replace NDL90REC = . if (NDL90REC >= 81 )
replace QC06 = . if (QC06 >= 81 )
replace QC09 = . if (QC09 >= 81 )
replace AL02 = . if (AL02 >= 81 )
replace SE04 = . if (SE04 >= 81 )
replace TR04 = . if (TR04 >= 81 )
replace ST04 = . if (ST04 >= 81 )
replace ST07 = . if (ST07 >= 81 )
replace AN04 = . if (AN04 >= 81 )
replace MJ04 = . if (MJ04 >= 81 )
replace IN04 = . if (IN04 >= 81 )
replace CC04 = . if (CC04 >= 81 )
replace CC11 = . if (CC11 >= 81 )
replace CK01 = . if (CK01 >= 81 )
replace LS05 = . if (LS05 >= 81 )
replace LS08 = . if (LS08 >= 81 )
replace HE04 = . if (HE04 >= 81 )
replace HE07 = . if (HE07 >= 81 )
replace ND02 = . if (ND02 >= 81 )
replace SP04 = . if (SP04 >= 81 )
replace SP08 = . if (SP08 >= 81 )
replace IRCDCIG = . if (IRCDCIG >= 81 )
replace IRCDMJ = . if (IRCDMJ >= 81 )
replace IREFCIG = . if (IREFCIG >= 81 )
replace IREFALC = . if (IREFALC >= 81 )
replace IREFMJ = . if (IREFMJ >= 81 )
replace IREFCOC = . if (IREFCOC >= 81 )
replace IRUDCIG = . if (IRUDCIG >= 81 )
replace IRUDALC = . if (IRUDALC >= 81 )
replace IRUDMJ = . if (IRUDMJ >= 81 )
replace IRUDCOC = . if (IRUDCOC >= 81 )
replace IRDPCIG = . if (IRDPCIG >= 81 )
replace IRDPALC = . if (IRDPALC >= 81 )
replace IRDPMJ = . if (IRDPMJ >= 81 )
replace IRDPCOC = . if (IRDPCOC >= 81 )
replace IRWSCIG = . if (IRWSCIG >= 81 )
replace IRWSALC = . if (IRWSALC >= 81 )
replace IRWSMJ = . if (IRWSMJ >= 81 )
replace IRWSCOC = . if (IRWSCOC >= 81 )
replace IRALCAGG = . if (IRALCAGG >= 81 )
replace IRALCARG = . if (IRALCARG >= 81 )
replace IRALCABS = . if (IRALCABS >= 81 )
replace IRALCHIG = . if (IRALCHIG >= 81 )
replace IRALCJOB = . if (IRALCJOB >= 81 )
replace IRALCMAT = . if (IRALCMAT >= 81 )
replace IRALCREL = . if (IRALCREL >= 81 )
replace IRALCFRD = . if (IRALCFRD >= 81 )
replace IRALCTOS = . if (IRALCTOS >= 81 )
replace IRALCHOL = . if (IRALCHOL >= 81 )
replace IRALCDRU = . if (IRALCDRU >= 81 )
replace IRALCINT = . if (IRALCINT >= 81 )
replace IRALCREM = . if (IRALCREM >= 81 )
replace IRALCQUI = . if (IRALCQUI >= 81 )
replace IRALCMOR = . if (IRALCMOR >= 81 )
replace IRALCSHO = . if (IRALCSHO >= 81 )
replace IRALCALO = . if (IRALCALO >= 81 )
replace IRALCBRK = . if (IRALCBRK >= 81 )
replace IRDEP = . if (IRDEP >= 81 )
replace IRARG = . if (IRARG >= 81 )
replace IRALN = . if (IRALN >= 81 )
replace IRANX = . if (IRANX >= 81 )
replace IRHLT = . if (IRHLT >= 81 )
replace IRNTK = . if (IRNTK >= 81 )
replace IRUPS = . if (IRUPS >= 81 )
replace IRLSW = . if (IRLSW >= 81 )
replace IRSSP = . if (IRSSP >= 81 )
replace IRCPE = . if (IRCPE >= 81 )
replace IREMG = . if (IREMG >= 81 )
replace IRDEP1 = . if (IRDEP1 >= 981 )
replace IRDEP2 = . if (IRDEP2 >= 981 )
replace IRDEP3 = . if (IRDEP3 >= 981 )
replace IRDEP4 = . if (IRDEP4 >= 981 )
replace IRDEP5 = . if (IRDEP5 >= 981 )
replace IRARG1 = . if (IRARG1 >= 981 )
replace IRARG2 = . if (IRARG2 >= 981 )
replace IRARG3 = . if (IRARG3 >= 981 )
replace IRARG4 = . if (IRARG4 >= 981 )
replace IRARG5 = . if (IRARG5 >= 981 )
replace IRALN1 = . if (IRALN1 >= 981 )
replace IRALN2 = . if (IRALN2 >= 981 )
replace IRALN3 = . if (IRALN3 >= 981 )
replace IRALN4 = . if (IRALN4 >= 981 )
replace IRALN5 = . if (IRALN5 >= 981 )
replace IRANX1 = . if (IRANX1 >= 981 )
replace IRANX2 = . if (IRANX2 >= 981 )
replace IRANX3 = . if (IRANX3 >= 981 )
replace IRANX4 = . if (IRANX4 >= 981 )
replace IRANX5 = . if (IRANX5 >= 981 )
replace IRHLT1 = . if (IRHLT1 >= 981 )
replace IRHLT2 = . if (IRHLT2 >= 981 )
replace IRHLT3 = . if (IRHLT3 >= 981 )
replace IRHLT4 = . if (IRHLT4 >= 981 )
replace IRHLT5 = . if (IRHLT5 >= 981 )
replace IRNTK1 = . if (IRNTK1 >= 981 )
replace IRNTK2 = . if (IRNTK2 >= 981 )
replace IRNTK3 = . if (IRNTK3 >= 981 )
replace IRNTK4 = . if (IRNTK4 >= 981 )
replace IRNTK5 = . if (IRNTK5 >= 981 )
replace IRUPS1 = . if (IRUPS1 >= 981 )
replace IRUPS2 = . if (IRUPS2 >= 981 )
replace IRUPS3 = . if (IRUPS3 >= 981 )
replace IRUPS4 = . if (IRUPS4 >= 981 )
replace IRUPS5 = . if (IRUPS5 >= 981 )
replace IRLSW1 = . if (IRLSW1 >= 981 )
replace IRLSW2 = . if (IRLSW2 >= 981 )
replace IRLSW3 = . if (IRLSW3 >= 981 )
replace IRLSW4 = . if (IRLSW4 >= 981 )
replace IRLSW5 = . if (IRLSW5 >= 981 )
replace IRSSP1 = . if (IRSSP1 >= 981 )
replace IRSSP2 = . if (IRSSP2 >= 981 )
replace IRSSP3 = . if (IRSSP3 >= 981 )
replace IRSSP4 = . if (IRSSP4 >= 981 )
replace IRSSP5 = . if (IRSSP5 >= 981 )
replace IRCPE1 = . if (IRCPE1 >= 981 )
replace IRCPE2 = . if (IRCPE2 >= 981 )
replace IRCPE3 = . if (IRCPE3 >= 981 )
replace IRCPE4 = . if (IRCPE4 >= 981 )
replace IRCPE5 = . if (IRCPE5 >= 981 )
replace IREMG1 = . if (IREMG1 >= 981 )
replace IREMG2 = . if (IREMG2 >= 981 )
replace IREMG3 = . if (IREMG3 >= 981 )
replace IREMG4 = . if (IREMG4 >= 981 )
replace IREMG5 = . if (IREMG5 >= 981 )
replace DEPCIG2 = . if (DEPCIG2 >= 81 )
replace DEPALC2 = . if (DEPALC2 >= 81 )
replace DEPMRJ2 = . if (DEPMRJ2 >= 81 )
replace DEPCOC2 = . if (DEPCOC2 >= 81 )
replace ARGCIG2 = . if (ARGCIG2 >= 81 )
replace ARGALC2 = . if (ARGALC2 >= 81 )
replace ARGMRJ2 = . if (ARGMRJ2 >= 81 )
replace ARGCOC2 = . if (ARGCOC2 >= 81 )
replace ALNCIG2 = . if (ALNCIG2 >= 81 )
replace ALNALC2 = . if (ALNALC2 >= 81 )
replace ALNMRJ2 = . if (ALNMRJ2 >= 81 )
replace ALNCOC2 = . if (ALNCOC2 >= 81 )
replace ANXCIG2 = . if (ANXCIG2 >= 81 )
replace ANXALC2 = . if (ANXALC2 >= 81 )
replace ANXMRJ2 = . if (ANXMRJ2 >= 81 )
replace ANXCOC2 = . if (ANXCOC2 >= 81 )
replace HLTCIG2 = . if (HLTCIG2 >= 81 )
replace HLTALC2 = . if (HLTALC2 >= 81 )
replace HLTMRJ2 = . if (HLTMRJ2 >= 81 )
replace HLTCOC2 = . if (HLTCOC2 >= 81 )
replace NTKCIG2 = . if (NTKCIG2 >= 81 )
replace NTKALC2 = . if (NTKALC2 >= 81 )
replace NTKMRJ2 = . if (NTKMRJ2 >= 81 )
replace NTKCOC2 = . if (NTKCOC2 >= 81 )
replace UPSCIG2 = . if (UPSCIG2 >= 81 )
replace UPSALC2 = . if (UPSALC2 >= 81 )
replace UPSMRJ2 = . if (UPSMRJ2 >= 81 )
replace UPSCOC2 = . if (UPSCOC2 >= 81 )
replace LSWCIG2 = . if (LSWCIG2 >= 81 )
replace LSWALC2 = . if (LSWALC2 >= 81 )
replace LSWMRJ2 = . if (LSWMRJ2 >= 81 )
replace LSWCOC2 = . if (LSWCOC2 >= 81 )
replace SSPCIG2 = . if (SSPCIG2 >= 81 )
replace SSPALC2 = . if (SSPALC2 >= 81 )
replace SSPMRJ2 = . if (SSPMRJ2 >= 81 )
replace SSPCOC2 = . if (SSPCOC2 >= 81 )
replace CPECIG2 = . if (CPECIG2 >= 81 )
replace CPEALC2 = . if (CPEALC2 >= 81 )
replace CPEMRJ2 = . if (CPEMRJ2 >= 81 )
replace CPECOC2 = . if (CPECOC2 >= 81 )
replace EMCIG2 = . if (EMCIG2 >= 81 )
replace EMALC2 = . if (EMALC2 >= 81 )
replace EMMRJ2 = . if (EMMRJ2 >= 81 )
replace EMCOC2 = . if (EMCOC2 >= 81 )
replace PRB1CIG = . if (PRB1CIG >= 81 )
replace PRB1ALC = . if (PRB1ALC >= 81 )
replace PRB1MRJ = . if (PRB1MRJ >= 81 )
replace PRB1COC = . if (PRB1COC >= 81 )
replace PRB2CIG = . if (PRB2CIG >= 81 )
replace PRB2ALC = . if (PRB2ALC >= 81 )
replace PRB2MRJ = . if (PRB2MRJ >= 81 )
replace PRB2COC = . if (PRB2COC >= 81 )
replace PRB3CIG = . if (PRB3CIG >= 81 )
replace PRB3ALC = . if (PRB3ALC >= 81 )
replace PRB3MRJ = . if (PRB3MRJ >= 81 )
replace PRB3COC = . if (PRB3COC >= 81 )
replace CHANCMJ2 = . if (CHANCMJ2 >= 81 )
replace CHANCOC2 = . if (CHANCOC2 >= 81 )
replace CHANHAL2 = . if (CHANHAL2 >= 81 )
replace CHANHER2 = . if (CHANHER2 >= 81 )
replace CWEOCC2 = . if (CWEOCC2 >= 981 )
replace ROCCUP2 = . if (ROCCUP2 >= 981 )
replace CWEBUS2 = . if (CWEBUS2 >= 981 )
replace BUSINES2 = . if (BUSINES2 >= 981 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

